@@ -2,7 +2,7 @@
 # The LearningOnline Network
 # CrGenerate - Generate a loncapa certificate request.
 #
-# $Id: CrGenerate.pl,v 1.8 2004/07/05 11:36:52 foxr Exp $
+# $Id: CrGenerate.pl,v 1.9 2009/02/02 13:27:45 schafran Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -108,7 +108,7 @@ sub DecodeEmailFromRequest {
 
     Debug("opening $RequestFile");
     open REQUEST, "< $RequestFile" or
-	die "Unable to open $RequestFile to parse return email address";
+	die "Unable to open $RequestFile to parse return e-mail address";
 
     Debug("Parsing request file");
     my $line;
@@ -121,7 +121,7 @@ sub DecodeEmailFromRequest {
 	}
     }
     if(!$found) {
-	die "There does not appear to be an email address in $RequestFile";
+	die "There does not appear to be an e-mail address in $RequestFile";
     }
 
     close REQUEST;
@@ -153,7 +153,7 @@ sub DecodeEmailFromRequest {
     Debug("Futher pulled out $addressequals");
 
     my ($junk, $address) = split(/=/, $addressequals);
-    Debug("Parsed final email addresss as $address");
+    Debug("Parsed final e-mail address as $address");
     
 
 
@@ -260,7 +260,7 @@ sub GenerateRequest {
     print "information.  Most of this information is for documentation\n";
     print "purposes only, so it's not critical if you make a mistake.\n";
     print "However:  The generated certificate will be sent to the \n";
-    print "Email address you provide, and you should leave the optional\n";
+    print "E-mail address you provide, and you should leave the optional\n";
     print "Challenge password blank.\n";
 
     my $requestcmd = $SSLCommand." req -newkey rsa:1024 "
@@ -369,7 +369,7 @@ sub MailRequest {
 
     my $FromEmail = DecodeEmailFromRequest("request.txt");
     if(!$FromEmail) {
-	die "From email address cannot be decoded from certificate request";
+	die "From e-mail address cannot be decoded from certificate request";
     }
     Debug("Certificate will be sent back to $FromEmail");
 
