@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Information about blocking status for Portfolio files
 #
-# $Id: blockedaccess.pm,v 1.6 2020/10/01 10:16:33 raeburn Exp $
+# $Id: blockedaccess.pm,v 1.7 2021/11/30 15:55:40 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -44,13 +44,14 @@ sub handler {
     &Apache::lonlocal::get_language_handle($r);
     my $ver_origurl = $r->uri;
     my $origurl = &Apache::lonnet::deversion($r->uri);
-    my ($blocked,$blocktext);
+    my ($blocked,$blocktext,$clientip);
+    $clientip = &Apache::lonnet::get_requestor_ip($r);
 
     if (&Apache::lonnet::is_portfolio_url($origurl)) {
         my ($type,$udom,$uname,$file_name,$group) = 
 	    &Apache::lonnet::parse_portfolio_url($origurl);
         ($blocked,$blocktext) = 
-            &Apache::loncommon::blocking_status('port',$uname,$udom);
+            &Apache::loncommon::blocking_status('port',$clientip,$uname,$udom);
     } else {
         if ($env{'request.course.id'}) {
             my $cnum = $env{'course.'.$env{'request.course.id'}.'.num'};
@@ -65,7 +66,7 @@ sub handler {
                 }
             }
             ($blocked,$blocktext) =
-                &Apache::loncommon::blocking_status('docs',$cnum,$cdom,$url,1,$symb,'blockedaccess');
+                &Apache::loncommon::blocking_status('docs',$clientip,$cnum,$cdom,$url,1,$symb,'blockedaccess');
         }
     }
     if ($blocked) {
