@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Firewall configuration to allow internal LON-CAPA communication between servers   
 #
-# $Id: Firewall.pm,v 1.22 2021/01/04 18:24:51 raeburn Exp $
+# $Id: Firewall.pm,v 1.25 2021/12/21 16:42:15 raeburn Exp $
 #
 # The LearningOnline Network with CAPA
 #
@@ -51,7 +51,7 @@ sub uses_firewalld {
         if ($1 >= 18) {
             $checkfirewalld = 1;
         }
-    } elsif ($distro =~ /^(?:centos|rhes|scientific|oracle)(\d+)/) {
+    } elsif ($distro =~ /^(?:centos|rhes|scientific|oracle|rocky|alma)(\d+)/) {
         if ($1 >= 7) {
             $checkfirewalld = 1;
         }
@@ -655,8 +655,8 @@ sub get_fw_chains {
     my $ubuntu_config = "/etc/ufw/ufw.conf";
     my $firewalld = &uses_firewalld($distro);
     if ($firewalld) {
-        my ($dist,$version) = ($distro =~ /^([\D]+)(\d+)$/);
-        if (((($dist eq 'rhes') || ($dist eq 'centos')) &&
+        my ($dist,$version) = ($distro =~ /^([\D]+)(\d+)(?:|\-stream)$/);
+        if (((($dist eq 'rhes') || ($dist eq 'centos') || ($dist eq 'rocky') || ($dist eq 'alma')) &&
              ($version >= 8)) || (($dist eq 'oracle') && ($version >= 7))) {
             push(@fw_chains,'INPUT');
         } else {
@@ -676,7 +676,7 @@ sub get_fw_chains {
         } else {
             if ($distro =~ /^(debian|ubuntu|suse|sles)/) {
                 @posschains = ('INPUT'); 
-            } elsif ($distro =~ /^(fedora|rhes|centos|scientific|oracle)(\d+)$/) {
+            } elsif ($distro =~ /^(fedora|rhes|centos|scientific|oracle|rocky|alma)(\d+)(?:|\-stream)$/) {
                 if ((($1 eq 'fedora') && ($2 > 15)) || (($1 ne 'fedora') && ($2 >= 7))) {
                     @posschains = ('INPUT');
                 } else {
@@ -689,7 +689,7 @@ sub get_fw_chains {
                         print("Unable to find iptables file containing static definitions.\n");
                     }
                 }
-                if ($distro =~ /^(fedora|rhes|centos|scientific|oracle)(\d+)$/) {
+                if ($distro =~ /^(fedora|rhes|centos|scientific|oracle|rocky|alma)(\d+)(?:|\-stream)$/) {
                     unless ((($1 eq 'fedora') && ($2 > 15)) || (($1 ne 'fedora') && ($2 >= 7))) {
                         push(@fw_chains,'RH-Firewall-1-INPUT');
                     }
