@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 #
 #Automated Enrollment script
-# $Id: Autoenroll.pl,v 1.34 2016/09/14 20:58:27 raeburn Exp $
+# $Id: Autoenroll.pl,v 1.37 2022/01/13 03:50:32 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -52,7 +52,7 @@
     foreach my $dom (@domains) {
         #only run if configured to
         my $run_enroll = 0;
-        my ($domsettings,$autofailsafe);
+        my ($domsettings,$autofailsafe,$autofailsafetype);
         my %domconfig =
             &Apache::lonnet::get_dom('configuration',['autoenroll','coursedefaults'],$dom);
         if (ref($domconfig{'autoenroll'}) eq 'HASH') {
@@ -63,6 +63,9 @@
             if ($domsettings->{'autofailsafe'} ne '') {
                 $autofailsafe = $domsettings->{'autofailsafe'};
             }
+            if ($domsettings->{'failsafe'} =~ /^(zero|any|off)$/) {
+                 $autofailsafetype = $domsettings->{'failsafe'};
+            }
         } else {
             $run_enroll = &localenroll::run($dom);
         }
@@ -74,6 +77,8 @@
         # Determine the courses
         my %courses = &Apache::lonnet::courseiddump($dom,'.',1,'.','.','.',1,\@hostids,'Course'); 
         my %affiliates = ();
+        my %unclutteredsec = ();
+        my %unclutteredlcsec = ();
         my %enrollvar = ();
         my %reply = ();
         my %LC_code = ();
@@ -120,17 +125,21 @@
                         $sections[0] = $enrollvar{$crs}{sectionnums};
                     }
                     if ($enrollvar{$crs}{crosslistings} =~ m/,/) {
-                        @crosslistings = split/,/,$enrollvar{$crs}{crosslistings}
+                        @crosslistings = split/,/,$enrollvar{$crs}{crosslistings};
                     } else {
                         @crosslistings = $enrollvar{$crs}{crosslistings};
                     }
+                    my $crscode = $enrollvar{$crs}{coursecode}; 
+                    my $crskey = $crs.':'.$crscode;
+                    @{$unclutteredsec{$crskey}} = ();
+                    @{$unclutteredlcsec{$crskey}} = (); 
                     foreach my $sec (@sections) {
                         if ($sec =~ m/^(\w+):(\w*)$/ ) {
-                            my $course_id = $enrollvar{$crs}{coursecode}.$1;
+                            my $instsec = $1; 
                             my $gp = $2;
-                            if (!grep/^\Q$course_id\E$/,@{$affiliates{$crs}}) {
-                                push @{$affiliates{$crs}}, $course_id;
-                                $LC_code{$crs}{$course_id} = $gp; 
+                            unless (grep/^\Q$instsec\E$/,@{$unclutteredsec{$crskey}}) {
+                                push(@{$unclutteredsec{$crskey}},$instsec);
+                                push(@{$unclutteredlcsec{$crskey}},$gp);
                             }
                         }
                     }
@@ -147,6 +156,19 @@
                 }
             }
         }
+        my %formattedsec = &Apache::lonnet::auto_instsec_reformat($dom,'clutter',\%unclutteredsec);
+        foreach my $crskey (keys(%formattedsec)) {
+            my ($crs,$instcode) = split(/:/,$crskey);
+            if ((ref($formattedsec{$crskey}) eq 'ARRAY') && (ref($unclutteredlcsec{$crskey}) eq 'ARRAY')) {
+                for (my $i=0; $i<@{$formattedsec{$crskey}}; $i++) {
+                    my $course_id = $instcode.$formattedsec{$crskey}[$i]; 
+                    unless (grep/^\Q$course_id\E$/,@{$affiliates{$crs}}) {
+                        push(@{$affiliates{$crs}},$course_id);
+                        $LC_code{$crs}{$course_id} = $unclutteredlcsec{$crskey}[$i];
+                    }
+                }
+            }
+        }
         my $outcome = &Apache::lonnet::fetch_enrollment_query('automated',\%affiliates,\%reply,$dom);
 
 # Now go through classes and perform required enrollment changes.
@@ -167,7 +189,11 @@
                         if ($enrollvar{$crs}{'autodropfailsafe'}) {
                             $failsafe = $enrollvar{$crs}{'autodropfailsafe'};
                         }
-                        my ($changecount,$response) = &LONCAPA::Enrollment::update_LC($dom,$crs,$enrollvar{$crs}{autoadds},$enrollvar{$crs}{autodrops},$enrollvar{$crs}{startdate},$enrollvar{$crs}{enddate},$enrollvar{$crs}{authtype},$enrollvar{$crs}{autharg},$showcredits,$defaultcredits,$failsafe,$affiliates{$crs},$LC_code{$crs},\$logmsg,\$newusermsg,'automated');
+                        my $failsafetype = $autofailsafetype;
+                        if ($enrollvar{$crs}{'autodropfailsafetype'}) {
+                            $failsafetype = $enrollvar{$crs}{'autodropfailsafetype'};  
+                        }
+                        my ($changecount,$response) = &LONCAPA::Enrollment::update_LC($dom,$crs,$enrollvar{$crs}{autoadds},$enrollvar{$crs}{autodrops},$enrollvar{$crs}{startdate},$enrollvar{$crs}{enddate},$enrollvar{$crs}{authtype},$enrollvar{$crs}{autharg},$showcredits,$defaultcredits,$failsafe,$failsafetype,$affiliates{$crs},$LC_code{$crs},\$logmsg,\$newusermsg,'automated');
                         print $fh &mt('Messages start for [_1]',$crs)."\n";
                         print $fh "$logmsg\n";
                         print $fh &mt('Messages end for [_1]',$crs)."\n";
