@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # input  definitons
 #
-# $Id: inputtags.pm,v 1.333.2.9 2019/12/04 02:10:23 raeburn Exp $
+# $Id: inputtags.pm,v 1.333.2.12 2021/12/12 21:21:44 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1152,7 +1152,11 @@ sub decideoutput {
         if ($target ne 'tex') {
            $message .= &Apache::loncommon::help_open_topic('Some_Items_Were_Not_Submitted');
         }
-	$css_class=$possible_class{'not_charged_try'};
+        if (&Apache::lonhomework::show_some_problem_status()) {
+            $css_class=$possible_class{'no_charge_warn'};
+        } else {
+            $css_class=$possible_class{'not_charged_try'};
+        }
 	$button = 1;
     } elsif ($award eq 'WRONG_NUMBOXESCHECKED') {
         $message = &mt('Number of boxes checked outside permissible range (either too few or too many).');
@@ -1201,7 +1205,7 @@ sub decideoutput {
     } elsif ($award eq 'SIG_FAIL') {
 	my ($used,$min,$max)=split(':',$awardmsg);
 	my $word = ($used < $min) ? 'more' : 'fewer';
-	$message = &mt("Submission not graded. Use $word significant figures.",$used);
+	$message = &mt("Submission not graded. Use $word significant figures.");
         if (&Apache::lonhomework::show_some_problem_status()) {
             $css_class=$possible_class{'no_charge_warn'};
         } else {
@@ -1216,21 +1220,37 @@ sub decideoutput {
     } elsif ($award eq 'UNIT_INVALID_STUDENT') {
 	$message = &mt('Unable to interpret units. Computer reads units as "[_1]".',&markup_unit($awardmsg,$target));
 	if ($target ne 'tex') {$message.=&Apache::loncommon::help_open_topic('Physical_Units');} 
-	$css_class=$possible_class{'not_charged_try'};
+        if (&Apache::lonhomework::show_some_problem_status()) {
+            $css_class=$possible_class{'no_charge_warn'};
+        } else {
+            $css_class=$possible_class{'not_charged_try'};
+        }
 	$button=1;
     } elsif ($award eq 'UNIT_FAIL' || $award eq 'UNIT_IRRECONCIBLE') {
 	$message = &mt('Incompatible units. No conversion found between "[_1]" and the required units.',&markup_unit($awardmsg,$target));
 	if ($target ne 'tex') {$message.=&Apache::loncommon::help_open_topic('Physical_Units');} 
-	$css_class=$possible_class{'not_charged_try'};
+        if (&Apache::lonhomework::show_some_problem_status()) {
+            $css_class=$possible_class{'no_charge_warn'};
+        } else {
+            $css_class=$possible_class{'not_charged_try'};
+        }
 	$button=1;
     } elsif ($award eq 'UNIT_NOTNEEDED') {
 	$message = &mt('Only a number required. Computer reads units of "[_1]".',&markup_unit($awardmsg,$target));
-	$css_class=$possible_class{'not_charged_try'};
+        if (&Apache::lonhomework::show_some_problem_status()) {
+            $css_class=$possible_class{'no_charge_warn'};
+        } else {
+            $css_class=$possible_class{'not_charged_try'};
+        }
 	$button=1;
     } elsif ($award eq 'NO_UNIT') {
 	$message = &mt("Units required").'.';
 	if ($target ne 'tex') {$message.=&Apache::loncommon::help_open_topic('Physical_Units')};
-	$css_class=$possible_class{'not_charged_try'};
+        if (&Apache::lonhomework::show_some_problem_status()) {
+            $css_class=$possible_class{'no_charge_warn'};
+        } else {
+            $css_class=$possible_class{'not_charged_try'};
+        }
 	$button=1;
     } elsif ($award eq 'COMMA_FAIL') {
 	$message = &mt("Proper comma separation is required").'.';
@@ -1879,13 +1899,15 @@ sub previous_tries {
     my $prefix = $env{'form.request.prefix'};
     $prefix =~ tr{.}{_};
     my $function_name = 'LONCAPA_previous_tries_'.$prefix;
-    if (($env{'request.state'} eq 'construct') || ($id =~ /[._]|[^\w\s\-]/)) {
+    if (($env{'request.state'} eq 'construct') || ($id =~ /\W/)) {
         $function_name .= $Apache::lonxml::curdepth;
     } else {
-        $function_name .= &js_escape($id);
+        $function_name .= $id;
     }
     $function_name .= '_'.$Apache::lonxml::counter;
-    my $result = &Apache::loncommon::modal_adhoc_window($function_name,420,410,$output,&mt($tries_text))."<br />";
+    my $possmathjax = 1;
+    my $result = &Apache::loncommon::modal_adhoc_window($function_name,420,410,$output,
+                                                        &mt($tries_text),$possmathjax)."<br />";
     return $result;
 }
 
