@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # random labelling tool
 #
-# $Id: randomlabel.pm,v 1.91.2.1 2008/12/21 15:10:12 raeburn Exp $
+# $Id: randomlabel.pm,v 1.96 2011/11/14 02:17:47 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -24,35 +24,84 @@
 # /home/httpd/html/adm/gpl.txt
 #
 # http://www.lon-capa.org/
-#
-# SYNTAX:
-# <randomlabel bgimg="URL" width="12" height="45" texwidth="50">
-#    <labelgroup name="GroupOne" type="image">
-#      <location x="123" y="456" />
-#      <location x="321" y="654" />
-#      <location x="213" y="546" />
-#      <label description="TEXT-1">IMG-URL</label>
-#      <label description="TEXT-2">IMG-URL</label>
-#      <label description="TEXT-3">IMG-URL</label>
-#    </labelgroup>
-#    <labelgroup name="GroupTwo" type="text">
-#      <location x="12" y="45" />
-#      <location x="32" y="65" />
-#      <location x="21" y="54" />
-#      <label>TEXT-1</label>
-#      <label>TEXT-2</label>
-#      <label>TEXT-3</label>
-#    </labelgroup>
-#   </randomlabel>
-#  ===========================================
-#  side effect:
-#    location (123,456): $GroupOne[0] = 2  # images give out indexes
-#             (321,654): $GroupOne[1] = 1
-#             (213,546): $GroupOne[2] = 0
-#    location (12,45)  : $GroupTwo[0] = "TEXT-3"
-#             (32,65)  : $GroupTwo[1] = "TEXT-1"
-#             (21,54)  : $GroupTwo[2] = "TEXT-2"
-#  ===========================================
+
+=pod
+
+=head1 NAME
+
+Apache::randomlable.pm
+
+=head1 SYNOPSIS
+
+Interface for producing applet code which
+randomizes the labelling of an image.
+
+This is part of the LearningOnline Network with CAPA project
+described at http://www.lon-capa.org.
+
+
+=head1 SYNTAX
+
+ <randomlabel bgimg="URL" width="12" height="45" texwidth="50">
+    <labelgroup name="GroupOne" type="image">
+      <location x="123" y="456" />
+      <location x="321" y="654" />
+      <location x="213" y="546" />
+      <label description="TEXT-1">IMG-URL</label>
+      <label description="TEXT-2">IMG-URL</label>
+      <label description="TEXT-3">IMG-URL</label>
+    </labelgroup>
+    <labelgroup name="GroupTwo" type="text">
+      <location x="12" y="45" />
+      <location x="32" y="65" />
+      <location x="21" y="54" />
+      <label>TEXT-1</label>
+      <label>TEXT-2</label>
+      <label>TEXT-3</label>
+    </labelgroup>
+   </randomlabel>
+  ===========================================
+  side effect:
+    location (123,456): $GroupOne[0] = 2   images give out indexes
+             (321,654): $GroupOne[1] = 1
+             (213,546): $GroupOne[2] = 0
+    location (12,45)  : $GroupTwo[0] = "TEXT-3"
+             (32,65)  : $GroupTwo[1] = "TEXT-1"
+             (21,54)  : $GroupTwo[2] = "TEXT-2"
+  ===========================================
+
+
+=head1 NOTABLE SUBROUTINES
+
+=over
+
+=item check_int()
+
+	utility function to do error checking on a integer.
+
+=item extract_tag_sizes()
+
+Parameters:
+      tag         - tag potentially containing height/width attributes.
+      def_width   - Default width.
+      def_height  - Default height.
+  Returns:
+      list containing width/height.
+
+=item get_label_width()
+
+	 Utility sub to compute the width of a label.
+	 
+=item end_labelgroup()
+
+begin to assign labels to locations
+
+=back
+
+=cut
+
+
+
 package Apache::randomlabel;
 use Apache::lonnet;
 use strict;
@@ -89,15 +138,8 @@ sub check_int {
     return $num;
 }
 
-#  Get width/height from an image tag...
-#
-#  Parameters:
-#      tag         - tag potentially containing height/width attributes.
-#      def_width   - Default width.
-#      def_height  - Default height.
-#  Returns:
-#      list containing width/height.
-#
+
+
 sub extract_tag_sizes {
     my ($tag, $dw, $dh) = @_;
     $tag =~ s/\s+/ /g;         # Collapse whitespace.
@@ -133,7 +175,7 @@ sub start_randomlabel {
     if ( defined($bgimg) && $bgimg !~ /^https?\:/ ) {
 	$bgimg=&Apache::lonnet::filelocation($Apache::lonxml::pwd[-1],$bgimg);
 	if (&Apache::lonnet::repcopy($bgimg) ne 'ok') {
-	    $bgimg='/home/httpd/html/adm/lonKaputt/lonlogo_broken.gif';
+	    $bgimg=$Apache::lonnet::perlvar{'lonDocRoot'}.'/adm/lonKaputt/lonlogo_broken.gif';
 	}
     }
     $Apache::randomlabel::obj_cnt=0;
@@ -181,7 +223,7 @@ sub end_randomlabel {
 	&Apache::lonnet::appenv(\%args);
     } elsif ($target eq 'tex') {
 	$result='\end{picture}\\\\';
-	$result.= ' \vskip -'.$height_param.' mm }  \\\\ ';
+	$result.= ' \vskip -'.$height_param.' mm } \\newline ';
     } elsif ($target eq 'edit') {
 	$result.=&Apache::edit::end_table;
     }
@@ -358,9 +400,8 @@ sub start_labelgroup {
     return $result;
 }
 
-#
-#   Utility sub to compute the width of a label.
-#
+
+
 sub get_label_width {
     my $label         = shift;
     &Apache::lonxml::debug("image label = $label");
@@ -410,7 +451,8 @@ sub add_vars {
     $out=Apache::run::run($code,$safeeval);
 }
 
-# begin to assign labels to locations
+
+
 sub end_labelgroup {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
     my $gname = $Apache::randomlabel::groupname;
