@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler for displaying the course catalog interface
 #
-# $Id: coursecatalog.pm,v 1.88.2.7 2019/08/02 00:24:02 raeburn Exp $
+# $Id: coursecatalog.pm,v 1.88.2.9 2021/12/12 21:47:58 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -58,6 +58,7 @@ sub handler {
                                             ['sortby','showdom']);
 
     my $codedom = &Apache::lonnet::default_login_domain();
+    my $hostname = $r->hostname();
 
     if (($env{'user.domain'} ne '') && ($env{'user.domain'} ne 'public')) { 
         $codedom = $env{'user.domain'};
@@ -124,7 +125,7 @@ sub handler {
         }
         my $js = '<script type="text/javascript">'."\n".
                  '// <![CDATA['."\n".
-                 &courselink_javascript($r)."\n".
+                 &courselink_javascript($hostname)."\n".
                  '// ]]>'."\n".
                  '</script>'."\n";
         $r->print(&Apache::loncommon::start_page('Search for a Course/Community',$js));
@@ -177,7 +178,8 @@ sub handler {
                                 if ($courseinfo{$codedom.'_'.$cnum}{'showsyllabus'}) {
                                     my $usehttp = 0;
                                     if (($ENV{'SERVER_PORT'} == 443) && ($courseinfo{$codedom.'_'.$cnum}{'extsyllplain'})) {
-                                        unless (&Apache::lonnet::uses_sts()) {
+                                        unless ((&Apache::lonnet::uses_sts()) ||
+                                                (&Apache::lonnet::waf_allssl($hostname))) {
                                             $usehttp = 1;
                                         }
                                     }
@@ -239,7 +241,8 @@ sub handler {
     &validate_input($codedom,\@cats,\%maxd,$cathash);
     my ($numtitles,@codetitles);
     if (($env{'form.coursenum'} ne '') && ($knownuser)) {
-        &course_details($r,$codedom,$formname,$domdesc,\@trails,\%allitems,\@codetitles);
+        &course_details($r,$codedom,$formname,$domdesc,$hostname,\@trails,
+                        \%allitems,\@codetitles);
     } else {
         my ($catlinks,$has_subcats,$selitem) = &category_breadcrumbs($codedom,@cats);
         my $wasacctext = &get_wasactive_text();
@@ -285,7 +288,7 @@ function setCourseId(caller) {
 }
 
 ENDSCRIPT
-        $catjs .= &courselink_javascript($r);
+        $catjs .= &courselink_javascript($hostname);
         if (&user_is_dc($codedom) || $canviewall) {
             $catjs .= <<ENDTOGGJS
 
@@ -320,7 +323,7 @@ ENDTOGGJS
                                                    $catlinks,$catjs,\@codetitles,$cattype,$canviewall);
             if ($env{'form.state'} eq 'listing') {
                 $r->print(&print_course_listing($codedom,$numtitles,undef,undef,undef,
-                                                \@codetitles,$canviewall));
+                                                \@codetitles,$canviewall,$hostname));
             }
         } else {
             my (%add_entries);
@@ -367,7 +370,7 @@ ENDJS
             }
             if ($env{'form.state'} eq 'listing') {
                 $r->print(&print_course_listing($codedom,undef,\@trails,\%allitems,$subcats,\@codetitles,
-                                                $canviewall));
+                                                $canviewall,$hostname));
             }
         }
     }
@@ -643,12 +646,12 @@ sub get_instcode_allowable {
 }
 
 sub course_details {
-    my ($r,$codedom,$formname,$domdesc,$trails,$allitems,$codetitles) = @_;
+    my ($r,$codedom,$formname,$domdesc,$hostname,$trails,$allitems,$codetitles) = @_;
     my $output;
     my %add_entries = (topmargin    => "0",
                        marginheight => "0",);
     my $js = '<script type="text/javascript">'."\n".
-             &courselink_javascript($r).'</script>'."\n";
+             &courselink_javascript($hostname).'</script>'."\n";
     my $start_page =
         &Apache::loncommon::start_page('Course/Community Catalog',$js,
                                        {'add_entries' => \%add_entries, });
@@ -675,7 +678,7 @@ sub course_details {
             &mt('Detailed community information:') :
             &mt('Detailed course information:')).
         '</h2>'.
-        &print_course_listing($codedom,undef,$trails,$allitems,undef,$codetitles).
+        &print_course_listing($codedom,undef,$trails,$allitems,undef,$codetitles,undef,$hostname).
         '<br />'.
         '<form name="'.$formname.'" method="post" action="/adm/coursecatalog">'.
         &Apache::lonhtmlcommon::actionbox([
@@ -711,8 +714,7 @@ END
 }
 
 sub courselink_javascript {
-    my ($r) = @_;
-    my $hostname = $r->hostname();    
+    my ($hostname) = @_;
     return <<"END";
 
 function ToSyllabus(cdom,cnum,usehttp) {
@@ -1289,7 +1291,7 @@ sub search_courselist {
 }
 
 sub print_course_listing {
-    my ($domain,$numtitles,$trails,$allitems,$subcats,$codetitles,$canviewall) = @_;
+    my ($domain,$numtitles,$trails,$allitems,$subcats,$codetitles,$canviewall,$hostname) = @_;
     my $output;
     my %courses;
     my $knownuser = &user_is_known();
@@ -1338,7 +1340,7 @@ sub print_course_listing {
     }
     my $now = time;
     $output .= &construct_data_table($knownuser,$domain,\%courses,$details,undef,
-                                     $now,$trails,$allitems,$canviewall);
+                                     $now,$trails,$allitems,$canviewall,$hostname);
     $output .= "\n".'<form name="linklaunch" method="post" action="">'.
                '<input type="hidden" name="backto" value="coursecatalog" />'.
                '<input type="hidden" name="courseid" value="" />'.
@@ -1347,7 +1349,8 @@ sub print_course_listing {
 }
 
 sub construct_data_table {
-    my ($knownuser,$domain,$courses,$details,$usersections,$now,$trails,$allitems,$canviewall) = @_;
+    my ($knownuser,$domain,$courses,$details,$usersections,$now,
+        $trails,$allitems,$canviewall,$hostname) = @_;
     my %sortname;
     if (($details eq '') || ($env{'form.showdetails'})) {
         $sortname{'Code'} = 'code';
@@ -1469,11 +1472,31 @@ sub construct_data_table {
     }
     my $count = 1;
     my $totalsec = 0;
+    my %clutteredxlists;
+    foreach my $course (keys(%courseinfo)) {
+        if (ref($courseinfo{$course}) eq 'HASH') {
+            if ($courseinfo{$course}{'xlist'} ne '') {
+                my $crskey = $courseinfo{$course}{'cnum'}.':'.$courseinfo{$course}{'code'};
+                my @xlists = split(/,\s/,$courseinfo{$course}{'xlist'});
+                $clutteredxlists{$crskey} = \@xlists;
+            }
+        }
+    }
+    if (keys(%clutteredxlists)) {
+        my %reformattedxlists = &Apache::lonnet::auto_instsec_reformat($domain,'declutter',\%clutteredxlists);
+        foreach my $crskey (keys(%reformattedxlists)) {
+            if (ref($reformattedxlists{$crskey}) eq 'ARRAY') {
+                my $course = $domain.'_'.(split(/:/,$crskey))[0];
+                $courseinfo{$course}{'xlist'} = join(', ',@{$reformattedxlists{$crskey}});
+            }
+        }
+    }
     foreach my $item (@sorted_courses) {
         foreach my $course (@{$Sortby{$item}}) {
             $output.=&Apache::loncommon::start_data_table_row(); 
             $output.=&courseinfo_row($courseinfo{$course},$knownuser,$details,
-                                     \$count,$now,$course,$trails,$allitems,\%numbers,$canviewall);
+                                     \$count,$now,$course,$trails,$allitems,
+                                     \%numbers,$canviewall,$hostname);
             $output.=&Apache::loncommon::end_data_table_row();
         }
     }
@@ -1793,7 +1816,8 @@ sub count_students {
 }
 
 sub courseinfo_row {
-    my ($info,$knownuser,$details,$countref,$now,$course,$trails,$allitems,$numbers,$canviewall) = @_;
+    my ($info,$knownuser,$details,$countref,$now,$course,$trails,$allitems,
+        $numbers,$canviewall,$hostname) = @_;
     my ($cdom,$cnum,$title,$ownerlast,$code,$owner,$seclist,$xlist_items,
         $accessdates,$showsyllabus,$counts,$autoenrollment,$output,$categories,
         $extsyllplain);
@@ -1840,7 +1864,8 @@ sub courseinfo_row {
     if ($showsyllabus) {
         my $usehttp = 0;
         if (($ENV{'SERVER_PORT'} == 443) && ($extsyllplain)) {
-            unless (&Apache::lonnet::uses_sts()) {
+            unless ((&Apache::lonnet::uses_sts()) ||
+                    (&Apache::lonnet::waf_allssl($hostname))) {
                 $usehttp = 1;
             }
         }
@@ -1924,13 +1949,19 @@ sub identify_sections {
 sub get_valid_classes {
     my ($seclist,$xlist_items,$crscode,$owners,$cdom,$cnum) = @_;
     my $response;
-    my (@sections,@xlists,%possclasses,%okclasses,%validations);
+    my (@sections,@format_sections,@xlists,%possclasses,%okclasses,%validations);
     @{$validations{'sections'}} = ();
     @{$validations{'xlists'}} = ();
     my $totalitems = 0;
     if ($seclist) {
         @sections = split(/,\s+/,$seclist);
-        map { $possclasses{$crscode.$_} = 1; } @sections;
+        my $crskey = $cnum.':'.$crscode;
+        my %formattedsec = &Apache::lonnet::auto_instsec_reformat($cdom,'clutter',
+                                                                  {$crskey => \@sections});
+        if (ref($formattedsec{$crskey}) eq 'ARRAY') {
+            @format_sections = @{$formattedsec{$crskey}};
+            map { $possclasses{$crscode.$_} = 1; } @format_sections;
+        }
     }
     if ($xlist_items) {
         @xlists = split(/,\s+/,$xlist_items);
@@ -1939,9 +1970,10 @@ sub get_valid_classes {
     my %okclasses = &Apache::lonnet::auto_validate_instclasses($cdom,$cnum,$owners,
                                                                \%possclasses);
     if (keys(%okclasses)) {
-        foreach my $sec (@sections) {
-            if ($okclasses{$crscode.$sec}) {
-                if (!grep(/^\Q$sec$\E/,@{$validations{'sections'}})) {
+        for (my $i=0; $i<@sections; $i++) {
+            if ($okclasses{$crscode.$format_sections[$i]}) {
+                my $sec = $sections[$i];
+                if (!grep(/^\Q$sec\E$/,@{$validations{'sections'}})) {
                     push(@{$validations{'sections'}},$sec);
                     $totalitems ++;
                 }
@@ -1962,6 +1994,13 @@ sub get_valid_classes {
                         join(', ',@{$validations{'sections'}}).'<br />';
         }
         if (@{$validations{'xlists'}}) {
+            my $crskey = $cnum.':'.$crscode;
+            my %reformattedxlists =
+                &Apache::lonnet::auto_instsec_reformat($cdom,'declutter',
+                                                       {$crskey => $validations{'xlists'}});
+            if (ref($reformattedxlists{$crskey}) eq 'ARRAY') {
+                $validations{'xlists'} = $reformattedxlists{$crskey};
+            }
             $response .= &mt('Courses:').' '.
                         join(', ',@{$validations{'xlists'}});
         }
