@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id 
+# $Id: grouproster.pm,v 1.10.2.2 2020/09/09 00:18:04 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -33,6 +33,7 @@ use Apache::loncommon;
 use Apache::lonhtmlcommon;
 use Apache::lonlocal;
 use Apache::longroup;
+use Apache::lonnavmaps;
 use LONCAPA;
 use Apache::Constants qw(:common :http);
 use lib '/home/httpd/lib/perl/';
@@ -160,14 +161,27 @@ function changeSort(caller) {
         $output .= '<h3>'.&mt('Group membership status - [_1]',$description).
                    '</h3>';
     } else {
+        my $view_permission =
+            &Apache::lonnet::allowed('vcg',$env{'request.course.id'}.($env{'request.course.sec'}?'/'.$env{'request.course.sec'}:''));
+        my $navmap=Apache::lonnavmaps::navmap->new();
+        my $grouppagelink = &Apache::longroup::get_group_link($cdom,$cnum,$group,$navmap,$view_permission,$refarg);
+        if ($grouppagelink) {
+            &Apache::lonhtmlcommon::add_breadcrumb
+            ({href=>$grouppagelink,
+              text=>&mt('Group').": $description",
+              title=>&mt("Go to group's home page"),
+              no_mt=>1},);
+        } else {
+            &Apache::lonhtmlcommon::add_breadcrumb
+            ({text=>&mt('Group').": $description",
+              no_mt=>1});
+        }
         &Apache::lonhtmlcommon::add_breadcrumb
-            ({href=>"/adm/$cdom/$cnum/$group/smppg?$refarg",
-              text=>"$ucgpterm: $description",
-              title=>"Go to group's home page"},
-             {href=>'/adm/grouproster?group='.$group.'&amp;'.$refarg,
-              text=>"Membership roster",
+             ({href=>'/adm/grouproster?group='.$group.'&amp;'.$refarg,
+              text=>"Membership Roster",
               title=>"Display group membership"},);
-        $output .= &Apache::lonhtmlcommon::breadcrumbs(&mt($gpterm.' membership status - [_1]',$description));
+        $output .= &Apache::lonhtmlcommon::breadcrumbs(&mt('Group membership status - [_1]',$description),
+                                                       undef,undef,undef,undef,1);
     }
     return $output;
 }
@@ -350,8 +364,8 @@ sub members_table_row {
             $privlist =~ s/, $//;
             $output .= '<td>'.$privlist.'</td>';
         } elsif ($view_details) {
-            $output .= '<td><nobr>'.join('&nbsp;&nbsp;&nbsp;',
-                      @{$$userinfo{'currtools'}}).'</nobr></td>';
+            $output .= '<td><span class="LC_nobreak">'.join('&nbsp;&nbsp;&nbsp;',
+                      @{$$userinfo{'currtools'}}).'</span></td>';
         }
     }
     $output .= &Apache::loncommon::end_data_table_row();
