@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Personal Information Page
 #
-# $Id: lonaboutme.pm,v 1.159 2020/12/18 15:23:02 raeburn Exp $
+# $Id: lonaboutme.pm,v 1.161 2021/11/30 15:55:37 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -108,6 +108,7 @@ sub handler {
         $is_course = &Apache::lonnet::is_course($cdom,$cnum);
     }
 
+    my $clientip = &Apache::lonnet::get_requestor_ip($r);
     my $candisplay = 1;
     if (!$is_course) {
         if ($action ne 'portfolio') {
@@ -153,7 +154,7 @@ sub handler {
                 '</ul>');
         } else {
             my ($blocked,$blocktext) =
-                &Apache::loncommon::blocking_status('port',$cnum,$cdom);
+                &Apache::loncommon::blocking_status('port',$clientip,$cnum,$cdom);
             if (!$blocked) {
                 &display_portfolio_files($r,$is_course);
             } else {
@@ -240,6 +241,17 @@ sub handler {
         my $start_page = &Apache::loncommon::start_page('Personal Information Page',$rss_link,$args);
         $r->print($start_page);
    }
+   my ($blocked,$blocktext) =
+       &Apache::loncommon::blocking_status('about',$clientip,$cnum,$cdom);
+   if ($blocked) {
+       if ($target eq 'tex') {
+           $r->print('\noindent{\large\textbf{'.&mt('No user personal information page available').'}}\\\\\\\\');
+       } else {
+           $r->print($blocktext);
+       }
+       $r->print(&Apache::loncommon::end_page());
+       return OK;
+   }
 
 #----------------Print Privacy note (edit mode) or last modified date. 
 
