@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler to set domain-wide configuration settings
 #
-# $Id: lonconfigsettings.pm,v 1.21.4.11 2019/08/27 20:43:52 raeburn Exp $
+# $Id: lonconfigsettings.pm,v 1.21.4.13 2021/12/28 02:32:31 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -214,8 +214,23 @@ $jscript
                 my $optionsprefix = 'LC_options_helpdesk_';
                 $onload .= "toggleHelpdeskRow(document.display,'overrides','$customclass','$optionsprefix');";
             }
+            if (grep(/^wafproxy$/,@actions)) {
+                $onload .= "toggleWAF();checkWAF();updateWAF();";
+            }
             if (grep(/^scantron$/,@actions)) {
-                $onload .= "toggleScantron('document.display');";
+                $onload .= "toggleScantron(document.display);";
+            }
+            if (grep(/^autoupdate$/,@actions)) {
+                $onload .= "toggleLastActiveDays(document.display);";
+            }
+            if (grep(/^autoenroll$/,@actions)) {
+                $onload .= "toggleFailsafe(document.display);";
+            }
+            if (grep(/^login$/,@actions)) {
+                my %domservers = &Apache::lonnet::get_servers($dom);
+                foreach my $server (sort(keys(%domservers))) {
+                    $onload .= "toggleSamlOptions(document.display,'$server');";
+                }
             }
             if ($onload) {
                 my %loaditems = (
@@ -303,7 +318,7 @@ sub make_changes {
        {href=>"javascript:changePage(document.$phase,'$phase')",
         text=>"Updated"});
     &print_header($r,$phase,$context,undef,$container);
-    my ($crstype,%lastact);
+    my ($crstype,%lastact,$errors);
     if ($context eq 'course') {
         $crstype = &Apache::loncommon::course_type();
     }
@@ -317,9 +332,10 @@ sub make_changes {
                                           $confname,$item,$roles,$values,\%lastact));
                 } else {
                     $changes{$item} = {};
-                    &Apache::courseprefs::process_changes($dom,$item,$values,
-                                                          $prefs->{$item},$changes{$item},
-                                                          $allitems,\%disallowed,$crstype);
+                    $errors =
+                        &Apache::courseprefs::process_changes($dom,$item,$values,
+                                                              $prefs->{$item},$changes{$item},
+                                                              $allitems,\%disallowed,$crstype);
                     if (keys(%{$changes{$item}}) > 0) {
                         $numchanged ++;
                     }
@@ -351,6 +367,9 @@ sub make_changes {
             }
             $r->print('</p>');
         }
+        if ($errors) {
+            $r->print('<p>'.$errors.'</p>');
+        }
     }
     $r->print('<p>');
     my $footer_text = 'Back to configuration display';
@@ -501,8 +520,8 @@ sub display_choices {
                 $thirddiv = 1;
             }
         }
-        $r->print('</div><br clear="all" />');
     }
+    $r->print('</div><div style="padding:0;clear:both;margin:0;border:0"></div>');
     $r->print(&print_footer($r,$phase,'display','Display',undef,$container,$parm_permission));
     $r->print('</form>');
     $r->print(&Apache::loncommon::end_page());
