@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonhelp.pm,v 1.44 2014/04/23 17:57:57 bisitz Exp $
+# $Id: lonhelp.pm,v 1.46 2017/04/01 13:55:32 raeburn Exp $
 #
 # .tex help system web server handler
 #
@@ -172,6 +172,8 @@ sub render {
     # Fix the pretty quotes
     $tex =~ s/('')|(``)/&quot;/g; #" to get emacs syntax highlighter happy
 
+    $tex =~ s/`/'/g;
+
     # For some reason all captions come out as "Figure 0:", so
     # just duck the issue...
 
@@ -276,6 +278,7 @@ sub handler {
 	 $filenames =~ s/:/,/g;
 	 my @files = split(/,/, $filenames);
          $firstfile = '/adm/help/'.$files[0].'.hlp';
+         my $count = 0;
 
 	 for my $filename (@files) {
 	     if (-e $docroot.'/adm/help/tex/'.
@@ -287,6 +290,10 @@ sub handler {
 					   . '/adm/help/tex/'.$filename.'.tex'))
 	         or return HTTP_NOT_FOUND;
 	     $tex .= join('', <$file>);
+             $count ++;
+             if (scalar(@files) > $count) {
+                 $tex .= '\hrulefill';
+             }
 	 }
 
 	 $text = &render($tex, $docroot);
