@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Directory Indexer
 #
-# $Id: lonindexer.pm,v 1.213.4.8 2015/01/23 22:59:28 raeburn Exp $
+# $Id: lonindexer.pm,v 1.213.4.9 2020/09/03 15:49:27 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -565,7 +565,7 @@ END
 	    } else {
 		$r->print($reshome);
 	    }
-	    $r->print("'>".&mt('Home').'</a></span>');
+	    $r->print("'>".&mt('Home directory').'</a></span>');
 	}
 	$r->print('</form>');
 # ------------------------------------------------------ Remember where we were
@@ -1088,8 +1088,13 @@ $r->print ('<input type="hidden" name="acts" value="" />');
 	my $quotable_filelink = &Apache::loncommon::escape_single($filelink);
         my $quotable_startdir = Apache::loncommon::escape_single($startdir);
         my $quotable_listname = &Apache::loncommon::escape_single($listname);
+        my $curfext = lc((split(/\./,$listname))[-1]);
+        my $modalstyle;
+        if ($curfext =~ /^js|css|txt|tab$/) {
+            $modalstyle = ",'','background-color:#ffffff'";
+        }
 
-	$r->print (" <a href=\"javascript:openMyModal('".$quotable_filelink."?inhibitmenu=yes',500,500,'yes');\">$listname</a> ");
+	$r->print (" <a href=\"javascript:openMyModal('".$quotable_filelink."?inhibitmenu=yes',500,500,'yes'".$modalstyle.");\">$listname</a> ");
 	$quotable_filelink = &Apache::loncommon::escape_single($filelink.'.meta');
 	&Apache::loncommon::inhibit_menu_check(\$quotable_filelink);
 	$r->print (" (<a href=\"javascript:openMyModal('".$quotable_filelink."?inhibitmenu=yes',500,500,'yes');\">".&mt('metadata')."</a>) ");
