@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Navigate Maps Display Handler
 #
-# $Id: lonnavdisplay.pm,v 1.22.4.7 2017/04/02 13:35:30 raeburn Exp $
+# $Id: lonnavdisplay.pm,v 1.22.4.10 2021/03/04 01:38:00 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -62,9 +62,15 @@ sub real_handler {
         return REDIRECT;
     }
 
+# ------------------------------------------------------------ Get query string
+    &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},['sort',
+                                                                  'showOnlyHomework',
+                                                                  'postsymb','register']);
     # Check if course needs to be re-initialized
     my $loncaparev = $r->dir_config('lonVersion');
     my ($result,@reinit) = &Apache::loncommon::needs_coursereinit($loncaparev);
+    my %prog_state=();
+    my $closure;
 
     if ($result eq 'switch') {
         &Apache::loncommon::content_type($r,'text/html');
@@ -72,10 +78,32 @@ sub real_handler {
         $r->print(&Apache::loncommon::check_release_result(@reinit));
         return OK;
     } elsif ($result eq 'update') {
-        my $cnum = $env{'course.'.$env{'request.course.id'}.'.num'};
-        my $cdom = $env{'course.'.$env{'request.course.id'}.'.domain'};
-        my ($furl,$ferr) = &Apache::lonuserstate::readmap("$cdom/$cnum");
+        my $cid = $env{'request.course.id'};
+        my $cnum = $env{'course.'.$cid.'.num'};
+        my $cdom = $env{'course.'.$cid.'.domain'};
+        &Apache::loncommon::content_type($r,'text/html');
+        $r->send_http_header;
+        &startpage($r);
+        my $preamble = '<div id="LC_update_'.$cid.'" class="LC_info">'.
+                       '<br />'.
+                       &mt('Your course session is being updated because of recent changes by course personnel.').
+                       ' '.&mt('Please be patient').'.<br /></div>'.
+                       '<div style="padding:0;clear:both;margin:0;border:0"></div>';
+        $closure = <<ENDCLOSE;
+<script type="text/javascript">
+// <![CDATA[
+\$("#LC_update_$cid").hide('slow');
+// ]]>
+</script>
+ENDCLOSE
+        %prog_state = &Apache::lonhtmlcommon::Create_PrgWin($r,undef,$preamble);
+        &Apache::lonhtmlcommon::Update_PrgWin($r,\%prog_state,&mt('Updating course'));
+        $r->rflush();
+        my ($furl,$ferr) = &Apache::lonuserstate::readmap("$cdom/$cnum",\%prog_state,$r);
+        &Apache::lonhtmlcommon::Update_PrgWin($r,\%prog_state,&mt('Finished!'));
         if ($ferr) {
+            &Apache::lonhtmlcommon::Close_PrgWin($r,\%prog_state);
+            $r->print($closure.&Apache::loncommon::end_page());
             my $requrl = $r->uri;
             $env{'user.error.msg'}="$requrl:bre:0:0:Course not initialized";
             $env{'user.reinit'} = 1;
@@ -87,39 +115,32 @@ sub real_handler {
     my $navmap = Apache::lonnavmaps::navmap->new();
 
     if (!defined($navmap)) {
+        if ($result eq 'update') {
+            &Apache::lonhtmlcommon::Close_PrgWin($r,\%prog_state);
+            $r->print($closure.&Apache::loncommon::end_page());
+        }
         my $requrl = $r->uri;
         $env{'user.error.msg'} = "$requrl:bre:0:0:Course not initialized";
         $env{'user.reinit'} = 1;
         return HTTP_NOT_ACCEPTABLE;
     }
 
-    # Send header, don't cache this page
-    &Apache::loncommon::content_type($r,'text/html');
-    $r->send_http_header;
-
-# ------------------------------------------------------------ Get query string
-    &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},['sort','showOnlyHomework','postsymb','register']);
-    
-# ----------------------------------------------------- Force menu registration
-    # Header
-    my $course_type = &Apache::loncommon::course_type();
-    my $title = $course_type . ' Contents';
-    my ($start_page,$args);
-    if ($env{'form.register'}) {
-        $args = {'force_register' => $env{'form.register'}};
-        $start_page = &Apache::loncommon::start_page($title,undef,$args);
+    if ($result eq 'update') {
+        $r->rflush();
+        &Apache::lonhtmlcommon::Close_PrgWin($r,\%prog_state);
+        $r->print($closure);
+        $r->rflush();
     } else {
-        my $brcrum = [{href => '/adm/navmaps',
-                       text => &mt($course_type . ' Contents'),
-                       no_mt => 1},
-                     ];
-        $args = {'bread_crumbs' => $brcrum};
-        $start_page = &Apache::loncommon::start_page($title,undef,$args);
+        # Send header, don't cache this page
+        &Apache::loncommon::content_type($r,'text/html');
+        $r->send_http_header;
+        &startpage($r);
     }
-    $r->print($start_page.
-              '<script type="text/javascript">window.focus();</script>');
+
     &startContentScreen($r,'navmaps');
-    $r->rflush();
+    unless ($result eq 'update') {
+        $r->rflush();
+    }
 
     # Check that it's defined
     if (!($navmap->courseMapDefined())) {
@@ -207,7 +228,7 @@ sub real_handler {
                      ."</span>");
         }
     } else {
-        my $link = 'navmaps?jumpToFirstHomework';
+        my $link = '/adm/navmaps?jumpToFirstHomework';
         if ($env{'form.register'}) {
             $link .= '&amp;register='.$env{'form.register'}; 
         }
@@ -230,7 +251,7 @@ sub real_handler {
         $filterFunc = sub { my $res = shift; 
                             return $res->completable() || $res->is_map();
                         };
-        my $link = 'navmaps?sort='.$env{'form.sort'};
+        my $link = '/adm/navmaps?sort='.$env{'form.sort'};
         if ($env{'form.register'}) {
             $link .= '&amp;register='.$env{'form.register'};
         }
@@ -242,7 +263,7 @@ sub real_handler {
         $env{'form.condition'} = 1;
 	$resource_no_folder_link = 1;
     } else {
-        my $link = 'navmaps?sort='.$env{'form.sort'}.'&amp;showOnlyHomework=1';
+        my $link = '/adm/navmaps?sort='.$env{'form.sort'}.'&amp;showOnlyHomework=1';
         if ($env{'form.register'}) {
             $link .= '&amp;register='.$env{'form.register'};
         }
@@ -304,6 +325,33 @@ sub real_handler {
     return OK;
 }
 
+sub startpage {
+    my ($r) = @_;
+# ----------------------------------------------------- Force menu registration
+    # Header
+    my $course_type = &Apache::loncommon::course_type();
+    my $title = $course_type . ' Contents';
+    my ($start_page,$args);
+    if ($env{'form.register'}) {
+        $args = {'force_register' => $env{'form.register'}};
+        $start_page = &Apache::loncommon::start_page($title,undef,$args);
+    } else {
+        my $brcrum = [{href => '/adm/navmaps',
+                       text => &mt($course_type . ' Contents'),
+                       no_mt => 1},
+                     ];
+        $args = {'bread_crumbs' => $brcrum};
+        $start_page = &Apache::loncommon::start_page($title,undef,$args);
+    }
+    $r->print($start_page.
+              '<script type="text/javascript">'."\n".
+              '// <![CDATA['."\n".
+              'window.focus();'."\n".
+              '// ]]>'."\n".
+              '</script>');
+    return;
+}
+
 sub startContentScreen {
     my ($r,$mode)=@_;
 
