@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # User Authentication Module
 #
-# $Id: lonremote.pm,v 1.31.2.2 2009/10/01 23:13:34 raeburn Exp $
+# $Id: lonremote.pm,v 1.34 2009/10/01 23:02:11 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -83,12 +83,12 @@ sub collapseremote {
     my $message='<div class="LC_warning"><b>'.&mt('The external menu (Remote Control) has been disabled, and you will be working with the smaller inline menu.').'</b></div>'."\n".
                 '<p>'.&mt('You may have either closed the Remote Control window, or it was blocked by a pop-up window filter in your browser.').'<br />'."\n".
                 &mt('To use the Remote Control, disable the filter for this site, and re-launch the Remote Control.').'</p>'."\n".
-                '<table><tr><td><fieldset><legend><b>'.&mt('Actions').'</b></legend><table><tr>'."\n".
-                '<td align="left">'.
-                '<a class="LC_menubuttons_link" href="/adm/remote?action=launch"><img alt="Launch Remote Control" src="/res/adm/pages/remotecontrol.png" border="0" />'.
+                '<table><tr><td><fieldset><legend>'.&mt('Actions').'</legend><table><tr>'."\n".
+                '<td class="LC_menubuttons_text" align="left">'.
+                '<a class="LC_menubuttons_link" href="/adm/remote?action=launch"><img alt="Launch Remote Control" src="/res/adm/pages/remotecontrol.png" class="LC_noBorder" />'.
                 &mt('Re-launch Remote Control').'</a></td><td>'.('&nbsp;'x3).'</td>'.
-                '<td align="right">'.
-                '<a class="LC_menubuttons_link" href="'.$lowerurl.'"><img alt="Launch Remote Control" src="/res/adm/pages/forw.png" border="0" />'.
+                '<td class="LC_menubuttons_text" align="right">'.
+                '<a class="LC_menubuttons_link" href="'.$lowerurl.'"><img alt="Launch Remote Control" src="/res/adm/pages/forw.png" class="LC_noBorder" />'.
                 &mt('Continue without Remote Control').'</a></td></tr></table>'.
                 '</fieldset></td></tr></table>'."\n".
                 '<p>'.&mt('Assuming no pop-up blocking, the Remote Control can be launched at any time from the [_1]Set User Preferences[_2] page, linked to in the [_3]Main Menu[_2].','<a href="/adm/preferences">','</a>','<a href="/adm/menu">').'</span></p>';
