@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Helpdesk request form
 #
-# $Id: lonsupportreq.pm,v 1.79.2.8 2021/01/04 03:46:06 raeburn Exp $
+# $Id: lonsupportreq.pm,v 1.79.2.10 2022/01/19 13:57:19 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -70,7 +70,7 @@ sub handler {
     }
     my $origurl = $env{'form.origurl'};
     if ($origurl =~ m{^https?://[^/]+(.*)$}) {
-        $origurl =~ $1;
+        $origurl = $1;
     }
     $origurl =~ s/(`)//g;
     $origurl =~ s/\$/\(\$\)/g;
@@ -393,7 +393,11 @@ ENDJS
     $i = $num%2;
     if ($knownuser) {
         if ($homeserver) {
-            unless ($helpform{'cc'} eq 'no') {
+            my $ip = &Apache::lonnet::get_requestor_ip($r);
+            my %setters;
+            my ($startblock,$endblock,$triggerblock,$by_ip,$blockdom) =
+                &Apache::loncommon::blockcheck(\%setters,'com',$ip);
+            unless (($helpform{'cc'} eq 'no') || ($by_ip)) {
                 $output .= &Apache::lonhtmlcommon::row_title($html_lt{'emac'},undef,$css[$i]).
                            '<input type="text" size="50" name="cc" value="" /><br />'."\n".
                            &Apache::lonhtmlcommon::row_closure();
@@ -663,7 +667,10 @@ sub print_request_receipt {
             return;
         }
     }
-    my $ip = &Apache::lonnet::get_requestor_ip();
+    my $ip = &Apache::lonnet::get_requestor_ip($r);
+    my %setters;
+    my ($startblock,$endblock,$triggerblock,$by_ip,$blockdom) =
+        &Apache::loncommon::blockcheck(\%setters,'com',$ip);
     my @ENVvars = ('HTTP_HOST','HTTP_USER_AGENT','SERVER_ADDR','SERVER_NAME');
     my @envvars = ('browser.os','browser.type','browser.version','user.home','request.role');
     my @loncvars = ('user.name','user.domain','request.course.sec','request.course.id');
@@ -709,7 +716,7 @@ sub print_request_receipt {
     unless ($helpform{'course'} eq 'no') {
         $formvars{'course'} = 1;
     }
-    unless ($helpform{'cc'} eq 'no') {
+    unless (($helpform{'cc'} eq 'no') || ($by_ip)) {
         $formvars{'cc'} = 1;
     }
     unless ($helpform{'screenshot'} eq 'no') {
