@@ -1,5 +1,5 @@
 #
-# $Id: studentcalc.pm,v 1.45 2010/06/14 01:30:54 raeburn Exp $
+# $Id: studentcalc.pm,v 1.46 2014/02/12 16:55:36 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -307,7 +307,7 @@ END
             } else {
                 $row_output .= '<td><a href="'.$resource->src.'?symb='.
                     &escape($resource->symb).
-                    '">Go&nbsp;To</a>';
+                    '"><span class="LC_nobreak">'.&mt('Go To').'</span></a>';
                 $row_output .= '</td><td>'.$resource->compTitle.'</td>';
             }
             if ($self->blackout() && $self->{'blackout_rows'}->{$rownum}>0) {
