@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonstathelpers.pm,v 1.74 2015/06/09 21:23:02 damieng Exp $
+# $Id: lonstathelpers.pm,v 1.76.2.5 2020/10/24 19:37:20 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -85,7 +85,7 @@ sub render_resource {
     ##
     ## Render the problem
     my ($base) = ($resource->src =~ m|^(.*/)[^/]*$|);
-    $base="http://".$ENV{'SERVER_NAME'}.$base;
+    $base=&Apache::lonnet::absolute_url().$base;
     my ($src,$symb)=($resource->link,&escape($resource->shown_symb));
     my $rendered_problem = &Apache::lonnet::ssi_body($src.'?symb='.$symb);
     $rendered_problem =~ s/<\s*form\s*/<nop /g;
@@ -135,9 +135,12 @@ Skips 'survey' problems.
 ####################################################
 ####################################################
 sub problem_selector {
-    my ($AcceptedResponseTypes,$sequence_addendum,$symbmode,$all,$prefix,$smallbox,$onclick) = @_;
+    my ($AcceptedResponseTypes,$sequence_addendum,$symbmode,$all,$prefix,
+        $byres,$include_tools,$smallbox,$onclick) = @_;
 # all: also make sequences selectable
 # prefix: prefix for all form names
+# byres: radiobutton shown per resource
+# include_tools: external tools included 
 # smallbox: use smaller box
 # onclick: javascript to execute when clicked
     my $Str;
@@ -156,6 +159,36 @@ sub problem_selector {
     foreach my $seq (@sequences) {
         my $seq_str = '';
         foreach my $res (&get_resources($navmap,$seq)) {
+            if ($res->src() eq '/res/lib/templates/simpleproblem.problem') {
+                next if (grep(/^placeholder$/,@{$res->parts}));
+            }
+            my $title = $res->compTitle;
+            if (! defined($title) || $title eq '') {
+                ($title) = ($res->src =~ m:/([^/]*)$:);
+            }
+            my $totalresps = 0;
+            if ($byres) {
+                foreach my $part (@{$res->parts}) {
+                    $totalresps += scalar($res->responseIds($part));
+                }
+                my $value = &HTML::Entities::encode($res->symb(),'<>&"');
+                my $checked;
+                if ($env{'form.problemchoice'} eq $res->symb()) {
+                    $checked = ' checked="checked"';
+                }
+                my $rowspan;
+                if ($totalresps > 1) {
+                    $rowspan = ' rowspan="'.$totalresps.'"';
+                }
+                $seq_str .= &Apache::loncommon::start_data_table_row().
+                            '<td'.$rowspan.' style="vertical-align:top">'.
+                            '<label><input type="radio" name="symb" value="'.$value.'"'.$checked.' />'.
+                            $title.'</label>';
+                my $link = $res->link.'?symb='.&escape($res->shown_symb);
+                $seq_str .= ('&nbsp;'x2).
+                            '<a target="preview" href="'.$link.'">'.&mt('view').'</a></td>';
+            }
+            my %partsseen;
             foreach my $part (@{$res->parts}) {
                 my @response_ids   = $res->responseIds($part);
                 my @response_types = $res->responseType($part);
@@ -163,54 +196,96 @@ sub problem_selector {
                     my $respid = $response_ids[$i];
                     my $resptype = $response_types[$i];
                     if ($resptype =~ m/$AcceptedResponseTypes/) {
-                        my $value = &make_target_id({symb=>$res->symb,
-                                                     part=>$part,
-                                                     respid=>$respid,
-                                                     resptype=>$resptype});
-                        my $checked = '';
-                        if ($env{'form.problemchoice'} eq $value) {
-                            $checked = ' checked="checked"';
+                        if ($byres) {
+                            if (exists($partsseen{$part})) {
+                                $seq_str .= &Apache::loncommon::continue_data_table_row();
+                            } else {
+                                my $parttitle = $part;
+                                if ($part eq '0') {
+                                    $parttitle = '';
+                                }
+                                if ($parttitle ne '') {
+                                    $parttitle = ('&nbsp;'x2).&mt('part').':&nbsp;'.$parttitle;
+                                }
+                                if (keys(%partsseen)) {
+                                    $seq_str .= &Apache::loncommon::continue_data_table_row();
+                                }
+                                unless ($partsseen{$part}) {
+                                    my $resprowspan;
+                                    if (scalar(@response_ids) > 1) {
+                                        $resprowspan = ' rowspan="'.scalar(@response_ids).'"';
+                                    }
+                                    $seq_str .= '<td'.$resprowspan.' style="vertical-align:top">'.
+                                                $parttitle.'</td>';
+                                    $partsseen{$part} = scalar(@response_ids);
+                                }
+                            }
+                            $seq_str .= '<td>'.$resptype;
+                            if (scalar(@response_ids) > 1) {
+                                $seq_str .= '&nbsp;'.&mt('id').':&nbsp;'.$respid;
+                            }
+                            $seq_str .= '</td>'. &Apache::loncommon::end_data_table_row()."\n";
+                        } else {
+                            my $value = &make_target_id({symb=>$res->symb,
+                                                         part=>$part,
+                                                         respid=>$respid,
+                                                         resptype=>$resptype});
+                            my $checked = '';
+                            if ($env{'form.problemchoice'} eq $value) {
+                                $checked = ' checked="checked"';
+                            }
+                            $seq_str .= &Apache::loncommon::start_data_table_row().
+                                ($symbmode?
+                                 '<td><input type="radio" id="'.$prefix.$rb_count.'" name="'.$prefix.'symb" value="'.&HTML::Entities::encode($res->symb,'<>&"').'" '.$checked.' '.
+                                 $jsadd.
+                                 ' /></td>'
+                                 :qq{<td><input type="radio" id="$rb_count" name="problemchoice" value="$value"$checked /></td>}).
+                                '<td><label for="'.$prefix.$rb_count.'">'.$resptype.'</label></td>'.
+                                '<td><label for="'.$prefix.$rb_count.'">'.$title.'</label>';
+                            if (scalar(@response_ids) > 1) {
+                                $seq_str .= &mt('response').' '.$respid;
+                            }
+                            my $link = $res->link.'?symb='.&escape($res->shown_symb);
+                            $seq_str .= ('&nbsp;'x2).
+                                        '<a target="preview" href="'.$link.'">'.&mt('view').'</a>';
+                            $seq_str .= "</td>". &Apache::loncommon::end_data_table_row()."\n";
                         }
-                        my $title = $res->compTitle;
-                        if (! defined($title) || $title eq '') {
-                            ($title) = ($res->src =~ m:/([^/]*)$:);
-                        }
-                        $seq_str .=  &Apache::loncommon::start_data_table_row().
-                            ($symbmode?
-                             '<td><input type="radio" id="'.$prefix.$rb_count.'" name="'.$prefix.'symb" value="'.&HTML::Entities::encode($res->symb,'<>&"').'" '.$checked.' '.
-                             $jsadd.
-                             ' /></td>'
-                            :qq{<td><input type="radio" id="$rb_count" name="problemchoice" value="$value"$checked /></td>}).
-                            '<td><label for="'.$prefix.$rb_count.'">'.$resptype.'</label></td>'.
-                            '<td><label for="'.$prefix.$rb_count.'">'.$title.'</label>';
-                        if (scalar(@response_ids) > 1) {
-                            $seq_str .= &mt('response').' '.$respid;
-                        }
-                        my $link = $res->link.'?symb='.&escape($res->shown_symb);
-                        $seq_str .= ('&nbsp;'x2).
-                            '<a target="preview" href="'.$link.'">'.&mt('view').'</a>';
-                        $seq_str .= "</td>". &Apache::loncommon::end_data_table_row()."\n";
                         $rb_count++;
                     }
                 }
             }
         }
         if ($seq_str ne '') {
-            $Str .= &Apache::loncommon::start_data_table_header_row().
-                '<th colspan="3">'.
-                ($all?'<input type="radio" id="'.$prefix.'s'.$rb_count.'" name="'.$prefix.'symb" value="'.&HTML::Entities::encode($seq->symb,'<>&').'" '.$jsadd.' />':'').
-                $seq->compTitle.'</th>'.
-                &Apache::loncommon::end_data_table_header_row()."\n".$seq_str;
-            if (defined($sequence_addendum)) {
+            if ($byres) {
                 $Str .= &Apache::loncommon::start_data_table_header_row().
-                    ('<td>&nbsp;</td>'x2).
-                    '<td align="right">'.$sequence_addendum.'</td>'.
-                    &Apache::loncommon::end_data_table_header_row()."\n";
+                        '<th colspan="3">'.$seq->compTitle.'</th>'.
+                        &Apache::loncommon::end_data_table_header_row().
+                        $seq_str;
+            } else {
+                $Str .= &Apache::loncommon::start_data_table_header_row().
+                    '<th colspan="3">'.
+                    ($all?'<input type="radio" id="'.$prefix.'s'.$rb_count.'" name="'.$prefix.'symb" value="'.&HTML::Entities::encode($seq->symb,'<>&').'" '.$jsadd.' />':'').
+                    $seq->compTitle.'</th>'.
+                    &Apache::loncommon::end_data_table_header_row()."\n".$seq_str;
+                if (defined($sequence_addendum)) {
+                    $Str .= &Apache::loncommon::start_data_table_header_row().
+                        ('<td>&nbsp;</td>'x2).
+                        '<td align="right">'.$sequence_addendum.'</td>'.
+                        &Apache::loncommon::end_data_table_header_row()."\n";
+                }
             }
         }
-
     }
     $Str .= &Apache::loncommon::end_data_table().&Apache::loncommon::end_scrollbox()."\n";
+    if (!$rb_count) {
+        if ($byres) {
+            $Str = '<p class="LC_info">'.&mt('No gradable problems found').'</p>';
+        } elsif ($AcceptedResponseTypes eq '.') {
+            $Str = '<p class="LC_info">'.&mt('No problems found').'</p>';
+        } else {
+            $Str = '<p class="LC_info">'.&mt('No analyzable problems found').'</p>';
+        }
+    }
     return $Str;
 }
 
