@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonstudentassessment.pm,v 1.162 2010/06/09 14:55:27 bisitz Exp $
+# $Id: lonstudentassessment.pm,v 1.169.2.7 2019/03/20 03:43:47 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -166,6 +166,8 @@ sub BuildStudentAssessmentPage {
         &Apache::lonstatistics::DisplayClasslist($r);
         return;
     }
+    $r->print(&Apache::lonhtmlcommon::breadcrumbs('Chart','Chart_Description:Chart_Sections:Chart_Student_Data:Chart_Enrollment_Status:Chart_Sequences:Chart_Output_Formats:Chart_Output_Data'));
+
     #
     # Print out the HTML headers for the interface
     #    This also parses the output mode selector
@@ -277,7 +279,7 @@ sub next_and_previous_buttons {
     # Build the 'all students' button
     my $all = '';
     $all .= '<input type="button" value="'.&mt('All Students').'" '.
-            '" onclick="document.Statistics.SelectedStudent.value='.
+            ' onclick="document.Statistics.SelectedStudent.value='.
             "''".';'.'document.Statistics.submit();" />';
     $Str .= $previousbutton.('&nbsp;'x5).$all.('&nbsp;'x5).$nextbutton;
     return $Str;
@@ -318,8 +320,6 @@ the chart page.
 #######################################################
 sub CreateInterface {
     my $Str = '';
-    $Str .= &Apache::lonhtmlcommon::breadcrumbs('Chart','Chart_Description:Chart_Sections:Chart_Student_Data:Chart_Enrollment_Status:Chart_Sequences:Chart_Output_Formats:Chart_Output_Data');
-#    $Str .= &CreateLegend();
     $Str .= '<table cellspacing="5">'."\n";
     $Str .= '<tr>';
     $Str .= '<td align="center"><b>'.&mt('Sections').'</b>'.
@@ -361,10 +361,6 @@ sub CreateInterface {
     $Str .= &CreateAndParseOutputDataSelector();
     $Str .= '</td></tr>'."\n";
     $Str .= '</table>'."\n";
-    $Str .= '<p>'
-           .&mt('Status:').' '
-           .'<input type="text" name="stats_status" size="60" value="" readonly="readonly" />'
-           .'</p>';
     $Str .= '<input type="submit" name="selectstudent" value="'.
         &mt('Select One Student').'" />';
     $Str .= '&nbsp;'x5;
@@ -431,7 +427,7 @@ my @OutputOptions =
 
 sub OutputDescriptions {
     my $Str = '';
-    $Str .= "<h2>Output Formats</h2>\n";
+    $Str .= '<h2>'.&mt('Output Formats')."</h2>\n";
     $Str .= "<dl>\n";
     foreach my $outputmode (@OutputOptions) {
 	$Str .="    <dt>".$outputmode->{'name'}."</dt>\n";
@@ -466,7 +462,7 @@ sub CreateAndParseOutputSelector {
     $Str = qq/<select size="5" name="$elementname">/;
     foreach my $option (@OutputOptions) {
         $Str .= "\n".'    <option value="'.$option->{'value'}.'"';
-        $Str .= " selected " if ($option->{'value'} eq $selected);
+        $Str .= ' selected="selected"' if ($option->{'value'} eq $selected);
         $Str .= ">".&mt($option->{'name'})."<\/option>";
     }
     $Str .= "\n</select>";
@@ -583,7 +579,7 @@ sub CreateAndParseOutputDataSelector {
     $Str = qq/<select size="5" name="$elementname">/;
     foreach my $option (@OutputDataOptions) {
         $Str .= "\n".'    <option value="'.$option->{'value'}.'"';
-        $Str .= " selected " if ($option->{'value'} eq $chosen_output->{'value'});
+        $Str .= ' selected="selected"' if ($option->{'value'} eq $chosen_output->{'value'});
         $Str .= ">".&mt($option->{'name'})."<\/option>";
     }
     $Str .= "\n</select>";
@@ -748,8 +744,6 @@ NEW_WINDOW_CHECKBOX
     $total_sum_width = length($total_count)+1;
     $Str .= "    total</pre>\n";
     $Str .= "<pre>";
-    $r->print($Str);
-    $r->rflush();
 
     $r->print(<<JS);
 <script type="text/javascript">
@@ -810,13 +804,13 @@ JS
     }
     #
     # Initialize progress window
-    %prog_state=&Apache::lonhtmlcommon::Create_PrgWin
-        ($r,'HTML Chart Status',
-         'HTML Chart Progress', $studentcount,
-         'inline',undef,'Statistics','stats_status');
     #
+    %prog_state=&Apache::lonhtmlcommon::Create_PrgWin($r,$studentcount);
     &Apache::lonhtmlcommon::Update_PrgWin($r,\%prog_state,
                                           'Processing first student');
+    $r->print($Str);
+    $r->rflush();
+
     return;
 }
 
@@ -841,6 +835,7 @@ sub html_outputstudent {
         if ($field eq 'comments') {
             $title = '<a href="/adm/'.$student->{'domain'}.'/'.$student->{'username'}.'/'.'aboutme#coursecomment">'.&mt('Comments').'</a>';
         }
+        utf8::decode($title);
         my $base = length($title);
         my $width=$Apache::lonstatistics::StudentData{$field}->{'width'};
         $Str .= $title.' 'x($width-$base).$padding;
@@ -874,16 +869,18 @@ sub html_outputstudent {
     my $PerformanceStr = '';
     foreach my $seq (@sequences) {
         my $symb = $seq->symb;
+        my $randompick = $seq->randompick();
         my ($performance,$performance_length,$score,$seq_max,$rawdata);
         if ($chosen_output->{'tries'}) {
             ($performance,$performance_length,$score,$seq_max,$rawdata) =
                 &student_tries_on_sequence($student,\%StudentsData,
-                                           $navmap,$seq,$show_links);
+                                           $navmap,$seq,$show_links,$randompick);
         } else {
             ($performance,$performance_length,$score,$seq_max,$rawdata) =
                 &student_performance_on_sequence($student,\%StudentsData,
                                                  $navmap,$seq,$show_links,
-                                                 $chosen_output->{ignore_weight});
+                                                 $chosen_output->{ignore_weight},
+                                                 $randompick);
         }
         my $ratio='';
         if ($chosen_output->{'every_problem'} && 
@@ -1103,9 +1100,9 @@ sub excel_initialize {
         &Apache::lonstatistics::selected_sequences_with_assessments();
     if (! ref($navmap)) {
         # Unable to get data, so bail out
-        $r->print("<h3>".
+        $r->print('<p class="LC_error">'.
                   &mt('Unable to retrieve course information.').
-                  '</h3>');
+                  '</p>');
     }
     #
     my $total_columns = scalar(&get_student_fields_to_show());
@@ -1120,9 +1117,9 @@ sub excel_initialize {
     }
     my $too_many_cols_error_message = 
         '<h2>'.&mt('Unable to Complete Request').'</h2>'.$/.
-        '<p>'.&mt('LON-CAPA is unable to produce your Excel spreadsheet because your selections will result in more than 255 columns.  Excel allows only 255 columns in a spreadsheet.').'</p>'.$/.
-        '<p>'.&mt('You may consider reducing the number of <b>Sequences or Folders</b> you have selected.').'</p>'.$/.
-        '<p>'.&mt('LON-CAPA can produce <b>CSV</b> files of this data or Excel files of the <b>Scores Summary</b> data.').'</p>'.$/;
+        '<p class="LC_warning">'.&mt('LON-CAPA is unable to produce your Excel spreadsheet because your selections will result in more than 255 columns.  Excel allows only 255 columns in a spreadsheet.').'</p>'.$/.
+        '<p>'.&mt('You may consider reducing the number of [_1]Sequences or Folders[_2] you have selected.','<b>','</b>').'</p>'.$/.
+        '<p>'.&mt('LON-CAPA can produce [_1]CSV[_2] files of this data or Excel files of the [_1]Scores Summary[_2] data.','<b>','</b>').'</p>'.$/;
     if ($chosen_output->{'base'} eq 'tries' && $total_columns > 255) {
         $r->print($too_many_cols_error_message);
         $request_aborted = 1;
@@ -1179,7 +1176,7 @@ sub excel_initialize {
     my $sectionstring = '';
     my @Sections = &Apache::lonstatistics::get_selected_sections();
     $excel_sheet->write($header_row,$cols_output++,
-                        &Apache::lonstatistics::section_and_enrollment_description('plaintext'),
+                        &Apache::lonstatistics::section_and_enrollment_description('localized'),
                         $format->{'h3'});
     #
     # Put the date in there too
@@ -1203,7 +1200,7 @@ sub excel_initialize {
     # Add the student headers
     $cols_output = 0;
     foreach my $field (&get_student_fields_to_show()) {
-        $excel_sheet->write($resource_name_row,$cols_output++,$field,
+        $excel_sheet->write($resource_name_row,$cols_output++,&mt($field),
                             $format->{'bold'});
     }
     #
@@ -1452,10 +1449,7 @@ sub excel_initialize {
     $r->rflush();
     #
     # Initialize progress window
-    %prog_state=&Apache::lonhtmlcommon::Create_PrgWin
-        ($r,'Excel File Compilation Status',
-         'Excel File Compilation Progress', $studentcount,
-         'inline',undef,'Statistics','stats_status');
+    %prog_state=&Apache::lonhtmlcommon::Create_PrgWin($r,$studentcount);
     #
     &Apache::lonhtmlcommon::Update_PrgWin($r,\%prog_state,
                                           'Processing first student');
@@ -1495,6 +1489,7 @@ sub excel_outputstudent {
     my %maximum_cell_translation;
     foreach my $seq (@sequences) {
         my $symb = $seq->symb;
+        my $randompick = $seq->randompick();
         $cols_output = $formula_data{$symb}->{'Excel:startcol'};
         # Keep track of cells to translate in total cell
         $total_cell_translation{$formula_data{$symb}->{'Excel:scorecell'}} = 
@@ -1509,12 +1504,13 @@ sub excel_outputstudent {
         if ($chosen_output->{'tries'} || $chosen_output->{'correct'}){
             ($performance,$performance_length,$score,$seq_max,$rawdata) =
                 &student_tries_on_sequence($student,\%StudentsData,
-                                           $navmap,$seq,'no');
+                                           $navmap,$seq,'no',$randompick);
         } else {
             ($performance,$performance_length,$score,$seq_max,$rawdata) =
                 &student_performance_on_sequence($student,\%StudentsData,
                                                  $navmap,$seq,'no',
-                                                 $chosen_output->{ignore_weight});
+                                                 $chosen_output->{ignore_weight},
+                                                 $randompick);
         } 
         if ($chosen_output->{'every_problem'}) {
             if ($chosen_output->{'correct'}) {
@@ -1647,30 +1643,28 @@ sub csv_initialize{
         &Apache::lonstatistics::selected_sequences_with_assessments();
     if (! ref($navmap)) {
         # Unable to get data, so bail out
-        $r->print("<h3>".
+        $r->print('<p class="LC_error">'.
                   &mt('Unable to retrieve course information.').
-                  '</h3>');
+                  '</p>');
     }
     #
     # Deal with unimplemented requests
     $request_aborted = undef;
     if ($chosen_output->{'base'} =~ /final table/) {
-        $r->print(<<END);
-<h2>Unable to Complete Request</h2>
-<p>
-The <b>Summary Table (Scores)</b> option is not available for non-HTML output.
-</p>
-END
-       $request_aborted = 1;
+        $r->print(
+            '<h2>'.&mt('Unable to Complete Request').'</h2>'
+           .'<p class="LC_warning">'
+           .&mt('The [_1]Summary Table (Scores)[_2] option'
+               .' is not available for non-HTML output.','<b>','</b>')
+           .'</p>'
+        );
+        $request_aborted = 1;
     }
     return if ($request_aborted);
     #
     # Initialize progress window
     my $studentcount = scalar(@Apache::lonstatistics::Students);
-    %prog_state=&Apache::lonhtmlcommon::Create_PrgWin
-        ($r,'CSV File Compilation Status',
-         'CSV File Compilation Progress', $studentcount,
-         'inline',undef,'Statistics','stats_status');
+    %prog_state=&Apache::lonhtmlcommon::Create_PrgWin($r,$studentcount);
     #
     # Open a file
     ($outputfile,$filename) = &Apache::loncommon::create_text_file($r,'csv');
@@ -1776,16 +1770,18 @@ sub csv_outputstudent {
     my $total = 0;
     my $maximum = 0;
     foreach my $seq (@sequences) {
+        my $randompick = $seq->randompick();
         my ($performance,$performance_length,$score,$seq_max,$rawdata);
         if ($chosen_output->{'tries'}){
             ($performance,$performance_length,$score,$seq_max,$rawdata) =
                 &student_tries_on_sequence($student,\%StudentsData,
-                                           $navmap,$seq,'no');
+                                           $navmap,$seq,'no',$randompick);
         } else {
             ($performance,$performance_length,$score,$seq_max,$rawdata) =
                 &student_performance_on_sequence($student,\%StudentsData,
                                                  $navmap,$seq,'no',
-                                                 $chosen_output->{ignore_weight});
+                                                 $chosen_output->{ignore_weight},
+                                                 $randompick);
         }
         if ($chosen_output->{'every_problem'}) {
             if ($chosen_output->{'correct'}) {
@@ -1886,7 +1882,7 @@ Inputs:
 #######################################################
 #######################################################
 sub student_tries_on_sequence {
-    my ($student,$studentdata,$navmap,$seq,$links) = @_;
+    my ($student,$studentdata,$navmap,$seq,$links,$randompick) = @_;
     $links = 'no' if (! defined($links));
     my $Str = '';
     my ($sum,$max) = (0,0);
@@ -1972,17 +1968,17 @@ sub student_tries_on_sequence {
                  ($links eq 'all')) {
                 my $link = '/adm/grades'.
                     '?symb='.&escape($resource->shown_symb).
-                        '&student='.$student->{'username'}.
-                            '&userdom='.$student->{'domain'}.
-                                '&command=submission';
+                        '&amp;student='.$student->{'username'}.
+                            '&amp;userdom='.$student->{'domain'}.
+                                '&amp;command=submission';
                 $symbol = &link($symbol, $link);
             }
             $value .= $symbol;
         }
         $Str .= $value;
     }
-    if ($seq->randompick()) {
-        $max = $seq->randompick();
+    if ($randompick) {
+        $max = $randompick;
     }
     if (! $hasdata && $sum == 0) {
         $sum = ' ';
@@ -2047,7 +2043,7 @@ Inputs:
 #######################################################
 #######################################################
 sub student_performance_on_sequence {
-    my ($student,$studentdata,$navmap,$seq,$links,$awarded_only) = @_;
+    my ($student,$studentdata,$navmap,$seq,$links,$awarded_only,$randompick) = @_;
     $links = 'no' if (! defined($links));
     my $Str = ''; # final result string
     my ($score,$max) = (0,0);
@@ -2056,9 +2052,11 @@ sub student_performance_on_sequence {
     my @ScoreData = ();
     my $partscore;
     my $hasdata = 0; # flag, 0 if there were no submissions on the sequence
+    my %ptsfreq;
     foreach my $resource (&get_resources($navmap,$seq)) {
         my $symb = $resource->symb;
         my $resource_data = $studentdata->{$symb};
+        my $resmax = 0;
         foreach my $part (@{$resource->parts()}) {
             $partscore = undef;
             my $weight;
@@ -2074,6 +2072,7 @@ sub student_performance_on_sequence {
             }
             #
             $max += $weight; # see the 'excused' branch below...
+            $resmax += $weight;
             $performance_length++; # one character per part
             $symbol = ' '; # default to space
             #
@@ -2127,13 +2126,24 @@ sub student_performance_on_sequence {
             if ( ($links eq 'yes' && $symbol ne ' ') || ($links eq 'all')) {
                 my $link = '/adm/grades' .
                     '?symb='.&escape($resource->shown_symb).
-                    '&student='.$student->{'username'}.
-                    '&userdom='.$student->{'domain'}.
-                    '&command=submission';
+                    '&amp;student='.$student->{'username'}.
+                    '&amp;userdom='.$student->{'domain'}.
+                    '&amp;command=submission';
                 $symbol = &link($symbol, $link);
             }
             $Str .= $symbol;
         }
+        if ($ptsfreq{$resmax}) {
+            $ptsfreq{$resmax} ++;
+        } else {
+            $ptsfreq{$resmax} = 1;
+        }
+    }
+    if ($randompick) {
+        my @uniquetotals = keys(%ptsfreq);
+        if ((@uniquetotals == 1) && ($ptsfreq{$uniquetotals[0]} > 0)) {
+            $max = $max * $randompick/$ptsfreq{$uniquetotals[0]};
+        }
     }
     if (! $hasdata && $score == 0) {
         $score = ' ';
