@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Japanese Localization Lexicon
 #
-# $Id: ja.pm,v 1.24 2009/05/07 12:42:17 bisitz Exp $
+# $Id: ja.pm,v 1.33 2014/02/28 19:23:30 bisitz Exp $
 #
 # Copyright i-Learning Limited Partnership Company
 #
@@ -34,52 +34,50 @@ use base qw(Apache::localize);
 %Lexicon=('_AUTO' => 1,
 'language_code' => 'ja',
 'char_encoding' => 'UTF-8',
-'date_locale'  => 
+'date_locale'  =>
       '$weekday, $day.$month.$year, $twentyfour:$minutes:$seconds',
 'date_months'  => '1,2,3,4,5,6,7,8,9,10,11,12',
 'date_days'    => '日,月,火,水,木,金,土',
 'date_am' => 'am',
 'date_pm' => 'pm',
-'textual_remote_display' => 'on',
 'htmlarea_lang' => 'ja-utf8',
 
-
-   'Arabic - UTF'
-=> 'ﺎﻠﻋﺮﺒﻳﺓ - UTF',
-
-   'German - UTF'
+   'Deutsch - UTF' # do not translate
 => 'Deutsch - UTF',
 
-   'English - UTF'
+   'English - UTF' # do not translate
 => 'English - UTF',
 
-   'Spanish (Castellan) - UTF'
-=> 'español (castellano) - UTF',
-
-   'Persian - UTF'
-=> 'ﺍیﺭﺎﻧی - UTF',
-
-   'French - UTF'
-=> 'français - UTF',
-
-   'Hebrew - UTF'
-=> 'עברית - UTF',
-
-   'Japanese - UTF'
-=> '日本語 - UTF',
-
-   'Portuguese - UTF'
+   'Português - UTF' # do not translate
 => 'Português - UTF',
 
-   'Russian - UTF'
-=> 'Русский - UTF',
+   'español (castellano) - UTF' # do not translate
+=> 'español (castellano) - UTF',
 
-   'Turkish - UTF'
+   'français - UTF' # do not translate
+=> 'français - UTF',
+
+   'türkçe - UTF' # do not translate
 => 'türkçe - UTF',
 
-   'Chinese Simplified - UTF'
+   'Русский - UTF' # do not translate
+=> 'Русский - UTF',
+
+   'עברית - UTF' # do not translate
+=> 'עברית - UTF',
+
+   '日本語 - UTF' # do not translate
+=> '日本語 - UTF',
+
+   '简体中文 - UTF' # do not translate
 => '简体中文 - UTF',
 
+   'ﺍیﺭﺎﻧی - UTF' # do not translate
+=> 'ﺍیﺭﺎﻧی - UTF',
+
+   'ﺎﻠﻋﺮﺒﻳﺓ - UTF' # do not translate
+=> 'ﺎﻠﻋﺮﺒﻳﺓ - UTF',
+
    'Swedish Chef - UTF'
 => 'Swedish Chef - UTF',
 
@@ -442,9 +440,6 @@ use base qw(Apache::localize);
 
 
 #SYNC Fri Sep 26 14:41:18 2003
-   ', and answers will be available on'
-=> ', 正解は次のリンクにあります',
-
    ', or the next time you log in.'
 => '、または次回のログイン。',
 
@@ -484,7 +479,7 @@ use base qw(Apache::localize);
    'Back to Directory'
 => 'ディレクトリに戻る',
 
-   'Bulletin Board'
+   'Discussion Board'
 => '掲示板',
 
    'Cancel'
@@ -493,8 +488,8 @@ use base qw(Apache::localize);
    'Changes will become active for your current session after'
 => '変更は次にログインしたときに有効になります',
 
-   'Construction Space Directory'
-=> 'コンストラクション・スペース・ディレクトリ',
+   'Authoring Space Directory'
+=> 'Authoring Space Directory', # 'コンストラクション・スペース・ディレクトリ',
 
    'Contact'
 => 'コンタクト',
@@ -556,7 +551,7 @@ use base qw(Apache::localize);
    'File'
 => 'ファイル',
 
-   'Found no analyzable parts in this problem, currently only Numerical, Formula and String response styles are supported.'
+   'Found no analyzable responses in this problem. Currently only Numerical, Formula and String response styles are supported.'
 => 'この問題の中に分析できない部分があります。現在、数字と数式と文字しかサポートされていません。',
 
    'Frequency'
@@ -688,8 +683,8 @@ use base qw(Apache::localize);
    'Select a'
 => '選択する：',
 
-   'Select the Construction Space'
-=> 'コンストラクション・スペースを選択する',
+   'Select the Authoring Space'
+=> 'Select the Authoring Space', # 'コンストラクション・スペースを選択する',
 
    'Sequence'
 => 'シーケンス',
@@ -814,8 +809,8 @@ use base qw(Apache::localize);
    'is closed but you are allowed to view it'
 => '締め切られましたが見ることは出来ます',
 
-   'is due at'
-=> 'の締切りは',
+   'is due at [_1]'
+=> 'の締切りは [_1]',
 
    'is in under construction'
 => 'は作成中です',
@@ -862,11 +857,11 @@ use base qw(Apache::localize);
    'undo'
 => 'やり直し',
 
-   'was due on'
-=> 'は締め切られました：',
+   'was due on [_1], and answers will be available on [_2]'
+=> 'は締め切られました：[_1], 正解は次のリンクにあります [_2]',
 
-   'will open on'
-=> 'は公開されます：',
+   'will open on [_1]'
+=> 'は公開されます：[_1]',
 
 #SYNC Fri Sep 26 16:57:10 2003
    ', is reserved internally by LON-CAPA.'
@@ -893,10 +888,10 @@ use base qw(Apache::localize);
    'Create a new course'
 => '新しいコースを作成する',
 
-   'Customized right of use ...	'
-=> '使用権限をカスタマイズする ...	',
+   'Customized right of use ...'
+=> '使用権限をカスタマイズする ...',
 
-   'Delete messages from bulletin boards'
+   'Delete messages from discussion boards'
 => '掲示板からメッセージを削除する',
 
    'Domain only - use limited to courses in the domain'
@@ -911,8 +906,8 @@ use base qw(Apache::localize);
    'Edit/Modify DOCS'
 => '編集 DOCS',
 
-   'Enter my resource construction space'
-=> '自分のコンストラクション・スペースに入る',
+   'Enter my Authoring Space'
+=> 'Enter my Authoring Space', # '自分のコンストラクション・スペースに入る',
 
    'FAIL'
 => '失敗',
@@ -971,8 +966,8 @@ use base qw(Apache::localize);
    'Public - no authentication or authorization required for use'
 => '公開 － 認証や認可無しに使用できます',
 
-   'Retrieval of an old version will overwrite the file currently in construction space'
-=> '古いバージョンを取り込むと、現在コンストラクション・スペースにあるファイルを上書きします',
+   'Retrieval of an old version will overwrite the file currently in Authoring Space.'
+=> 'Retrieval of an old version will overwrite the file currently in Authoring Space.', # '古いバージョンを取り込むと、現在コンストラクション・スペースにあるファイルを上書きします',
 
    'Retrieve previous versions of'
 => '前のバージョンを取り出す：',
@@ -1056,8 +1051,8 @@ use base qw(Apache::localize);
    'Collapse Remote Control'
 => 'リモコン・パネルを消します',
 
-   'Construction Space'
-=> 'コンストラクション・スペース',
+   'Authoring Space'
+=> 'Authoring Space', # 'コンストラクション・スペース',
 
    'Content changed'
 => 'コンテンツが変更されました',
@@ -1092,8 +1087,8 @@ use base qw(Apache::localize);
    'Differences'
 => '違い',
 
-   'Dump Course DOCS to Construction Space'
-=> 'コンストラクション・スペースにＤＯＣＳをダンプする',
+   'Copy Course Content to Authoring Space'
+=> 'Copy Course Content to Authoring Space', # 'コンストラクション・スペースにＤＯＣＳをダンプする',
 
    'Entering course ...'
 => 'コースに入る ...',
@@ -1632,15 +1627,6 @@ use base qw(Apache::localize);
    'enter[_1]'
 => '入力',
 
-# ----
-
-   'send[_1]'
-=> 'send',
-
-   'scantron[_1]'
-=> 'scantron',
-
-
 # ----
 
    'view[_1]'
