@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler to cleanup XML files
 #
-# $Id: loncleanup.pm,v 1.11 2009/09/09 17:58:37 bisitz Exp $
+# $Id: loncleanup.pm,v 1.20 2013/06/04 22:20:16 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -34,13 +34,13 @@ use strict;
 use Apache::File;
 use File::Copy;
 use Apache::Constants qw(:common :http :methods);
-use Apache::loncacc;
 use Apache::loncommon();
 use Apache::lonhtmlcommon();
 use Apache::lonlocal;
 use Apache::lonnet;
 use lib '/home/httpd/lib/perl/';
 use LONCAPA;
+use HTML::Entities();
  
 
 sub latextrans {
@@ -252,17 +252,22 @@ sub phaseone {
     $r->print(
         &Apache::lonhtmlcommon::start_pick_box()
        .&Apache::lonhtmlcommon::row_title(&mt('Select actions to attempt'))
+       .'<label>'
        .'<input type="checkbox" name="linefeed" checked="checked" /> '
        .&mt('Linefeeds, formfeeds, and carriage returns')
-       .'<br />'
+       .'</label><br />'
+       .'<label>'
        .'<input type="checkbox" name="empty" checked="checked" /> '
        .&mt('Empty tags')
-       .'<br />'
+       .'</label><br />'
+       .'<label>'
        .'<input type="checkbox" name="lower" checked="checked" /> '
        .&mt('Lower casing')
-       .'<br />'
+       .'</label><br />'
+       .'<label>'
        .'<input type="checkbox" name="symbol" checked="checked" /> '
        .&mt('Symbol font')
+       .'</label>'
        .&Apache::lonhtmlcommon::row_closure(1)
        .&Apache::lonhtmlcommon::end_pick_box()
     );
@@ -278,13 +283,29 @@ sub phaseone {
 sub phasetwo {
     # Check original file
     my ($r,$fn,$uname,$udom)=@_;
-    open(IN,'/home/'.$uname.'/public_html/'.$fn);
     my $text='';
-    while (my $line=<IN>) {
-	$text.=$line;
+    my $londocroot = $r->dir_config('lonDocRoot');
+    if (open(IN,"<$londocroot/priv/$udom/$uname".$fn)) {
+        while (my $line=<IN>) {
+	    $text.=$line;
+        }
+        close(IN);
     }
-    close(IN);
-    my $uri='/~'.$uname.$fn;
+    # Check if any selection was made
+    if ($env{'form.linefeed'} ne 'on' &&
+        $env{'form.empty'} ne 'on' &&
+        $env{'form.lower'} ne 'on' &&
+        $env{'form.symbol'} ne 'on') {
+        $r->print(
+            '<p class="LC_warning">'
+           .&mt('Please select at least one option.')
+           .'</p>'
+           .'<p><a href="javascript:history.back();">'.&mt('Back').'</p>'
+        );
+        return;
+    }
+
+    my $uri="/priv/$udom/$uname".$fn;
     my $result=&Apache::lonnet::ssi_body($uri,
 					 ('grade_target'=>'web',
 					  'return_only_error_and_warning_counts' => 1));
@@ -310,10 +331,11 @@ sub phasetwo {
                ($env{'form.symbol'} ne 'on'));
     my ($main,$ext)=($fn=~/^(.*)\.(\w+)/);
     my $newfn=$main.'_Auto_Cleaned_Up.'.$ext;
-    open(OUT,'>/home/'.$uname.'/public_html'.$newfn);
-    print OUT $text;
-    close(OUT);
-    my $newuri='/~'.$uname.$newfn;
+    if (open(OUT,">$londocroot/priv/$udom/$uname".$newfn)) {
+        print OUT $text;
+        close(OUT);
+    }
+    my $newuri="/priv/$udom/$uname".$newfn;
     $result=&Apache::lonnet::ssi_body($newuri,
                                          ('grade_target'=>'web',
                                           'return_only_error_and_warning_counts' => 1));
@@ -337,8 +359,11 @@ sub phasetwo {
        .'<li><a href="'.$newuri.'" target="prev">'
        .&mt('Open (and edit) cleaned up file in new window')
        .'</a></li>'
-       .'<li><a href="/adm/diff?filename='.&escape($uri)
-       .'&versionone=priv&filetwo='.&escape($newuri).'" target="prev">'
+       .'<li><a href="'
+       .&HTML::Entities::encode(
+            '/adm/diff?filename='.&escape($uri)
+           .'&versionone=priv&filetwo='.&escape($newuri))
+       .'" target="prev">'
        .&mt('Show diffs in new window')
        .'</a></li>'
        .'</ul>'
@@ -356,25 +381,29 @@ sub phasetwo {
 
 sub phasethree {
     my ($r,$fn,$uname,$udom)=@_;
-    my $old='/home/'.$uname.'/public_html/'.$fn;
+    my $old=$r->dir_config('lonDocRoot')."/priv/$udom/$uname".$fn;
     my ($main,$ext)=($fn=~/^(.*)\.(\w+)/);
     my $newfn=$main.'_Auto_Cleaned_Up.'.$ext;
-    my $new='/home/'.$uname.'/public_html'.$newfn;
+    my $new=$r->dir_config('lonDocRoot')."/priv/$udom/$uname".$newfn;
     if ($env{'form.accept'}) {
-	$r->print(
+        $r->print(
         '<p class="LC_info">'
-       .&mt('Accepting changes')
+       .&mt('Accepting changes...')
        .'</p>'
     );
         move($new,$old);
     } else {
-	$r->print(
+        $r->print(
         '<p class="LC_info">'
-       .&mt('Rejecting changes')
+       .&mt('Rejecting changes...')
        .'</p>'
-    );
+        );
         unlink($new);
     }
+    $r->print(
+        '<p>'
+       .&Apache::lonhtmlcommon::confirm_success(&mt('Done')));
+        '</p>'
 }
 
 # ---------------------------------------------------------------- Main Handler
@@ -390,7 +419,7 @@ sub handler {
 
     if ($env{'form.filename'}) {
 	$fn=$env{'form.filename'};
-	$fn=~s/^https?\:\/\/[^\/]+//;
+	$fn=~s{^https?\://[^/]+}{};
     } else {
 	$r->log_reason($env{'user.name'}.' at '.$env{'user.domain'}.
 		       ' unspecified filename for cleanup', $r->filename); 
@@ -407,8 +436,7 @@ sub handler {
     my $uname;
     my $udom;
 
-    ($uname,$udom)=
-	&Apache::loncacc::constructaccess($fn,$r->dir_config('lonDefDomain'));
+    ($uname,$udom)=&Apache::lonnet::constructaccess($fn);
     unless (($uname) && ($udom)) {
 	$r->log_reason($uname.' at '.$udom.
 		       ' trying to cleanup file '.$env{'form.filename'}.
@@ -417,17 +445,17 @@ sub handler {
 	return HTTP_NOT_ACCEPTABLE;
     }
 
-    $fn=~s{/~($LONCAPA::username_re)}{};
-
     &Apache::loncommon::content_type($r,'text/html');
     $r->send_http_header;
 
     # Breadcrumbs
-    my $brcrum = [{'href' => &Apache::loncommon::authorspace(),
-                   'text' => 'Construction Space'},
+    my $brcrum = [{'href' => &Apache::loncommon::authorspace($fn),
+                   'text' => 'Authoring Space'},
                   {'href' => '',
                    'text' => 'Cleanup XML Document'}];
 
+    $fn=~s{^/priv/$LONCAPA::domain_re/$LONCAPA::username_re}{};
+
     $r->print(&Apache::loncommon::start_page('Cleanup XML Document',
                                              undef,
                                              {'bread_crumbs' => $brcrum,}));
@@ -435,7 +463,7 @@ sub handler {
               '<form action="/adm/cleanup" method="post">'.
               '<input type="hidden" name="filename" value="'.$env{'form.filename'}.'" />');
     unless ($fn=~/\.(problem|exam|quiz|assess|survey|form|library|xml|html|htm|xhtml|xhtm|sty)$/) {
-	$r->print(&mt('Cannot cleanup this filetype'));
+	$r->print('<p class="LC_warning">'.&mt('Cannot cleanup this filetype').'</p>');
     } else {
 	if ($env{'form.phase'} eq 'three') {
 	    &phasethree($r,$fn,$uname,$udom);
@@ -446,15 +474,14 @@ sub handler {
 	}
     }
     my $dir=$fn;
-    $dir=~s/\/[^\/]+$/\//;
+    $dir=~s{[^/]+$}{};
     $r->print(
         '</form>'
-       .&Apache::lonhtmlcommon::start_funclist()
-       .&Apache::lonhtmlcommon::add_item_funclist(
-            '<a href="/priv/'.$uname.'/'.$fn.'">'.&mt('Back to Source File').'</a>')
-       .&Apache::lonhtmlcommon::add_item_funclist(
-            '<a href="/priv/'.$uname.'/'.$dir.'">'.&mt('Back to Source Directory').'</a>')
-       .&Apache::lonhtmlcommon::end_funclist()
+       .&Apache::lonhtmlcommon::actionbox(
+            ['<a href="/priv/'.$udom.'/'.$uname.$fn.'">'.
+                 &mt('Back to Source File').'</a>',
+            '<a href="/priv/'.$udom.'/'.$uname.$dir.'">'.
+                &mt('Back to Source Directory').'</a>'])
        .&Apache::loncommon::end_page()
     );
 
