@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler to show differences between file versions
 #
-# $Id: londiff.pm,v 1.37 2013/06/04 22:20:16 raeburn Exp $
+# $Id: londiff.pm,v 1.38 2017/05/07 13:26:40 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -85,7 +85,8 @@ sub handler {
     if ($env{'form.filename'}=~ m{^/res/}) {
         if (&Apache::lonnet::allowed('bre',$env{'form.filename'})) {
             if ($env{'request.course.id'}) {
-                if (&Apache::lonnet::allowed('mdc',$env{'request.course.id'})) {
+                if ((&Apache::lonnet::allowed('mdc',$env{'request.course.id'})) ||
+                    (&Apache::lonnet::allowed('cev',$env{'request.course.id'}))) {
                     $allowed = 1;
                 }
             } else {
