@@ -2,7 +2,7 @@
 #
 # Sequence Handler
 #
-# $Id: lonsequence.pm,v 1.48.2.2 2020/09/03 12:49:17 raeburn Exp $
+# $Id: lonsequence.pm,v 1.48.2.4 2021/12/14 21:38:14 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -278,7 +278,8 @@ sub handler {
                    }
                    push(@crumbs,{text => $maptitle, no_mt => 1});
                    $args = {'bread_crumbs' => \@crumbs,
-                            'bread_crumbs_nomenu' => 1};
+                            'bread_crumbs_nomenu' => 1,
+                            'no_auto_mt_title' => 1};
                    $r->print(&Apache::loncommon::start_page($maptitle,undef,$args));
 
                    my $renderArgs = { 'cols'                    => [0,1,2,3],
@@ -411,7 +412,7 @@ sub handler {
                                     'last_known' => [$disurl,$dismapid]);
       }
       &Apache::loncommon::content_type($r,'text/html');
-      $r->header_out(Location => &Apache::lonnet::absolute_url($ENV{'SERVER_NAME'}).
+      $r->header_out(Location => &Apache::lonnet::absolute_url().
                                  $showdisurl);
       return REDIRECT;
    } else {
